@@ -1,19 +1,25 @@
-# SutekhInfo.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2007 Simon Cross <hodgestar@gmail.com>
 # GPL - see COPYING for details
 
 """Requirements and such for setuptools"""
 
 # pylint doesn't see resource_string for some reason
-# pylint: disable-msg=E0611
+# pylint: disable=no-name-in-module
 from pkg_resources import resource_string
 
+# license constants to simplify things a bit
 
-# pylint: disable-msg=R0903,C0111
-class SutekhInfo(object):
-    VERSION = (0, 8, 6, 'final', 0)
+GPL = 'License :: OSI Approved :: GNU General Public License (GPL)'
+LGPL = 'License :: OSI Approved :: GNU Library or Lesser General ' \
+    'Public License (LGPL)'
+MIT = 'License :: OSI Approved :: MIT License'
+PYTHON = 'License :: OSI Approved :: Python Software Foundation License'
+
+# pylint: disable=too-few-public-methods, missing-docstring
+class SutekhInfo:
+    VERSION = (2, 0, 0, 'final', 1)
     BASE_VERSION_STR = '.'.join([str(x) for x in VERSION[:3]])
     VERSION_STR = {
         'final': BASE_VERSION_STR,
@@ -26,7 +32,7 @@ class SutekhInfo(object):
 
     PEOPLE = {
         'Simon': ('Simon Cross', 'hodgestar+sutekh@gmail.com'),
-        'Neil': ('Neil Muller', 'drnmuller+sutekh@gmail.com'),
+        'Neil': ('Neil Muller', 'drnlmuller+sutekh@gmail.com'),
         'Adrianna': ('Adrianna Pinska', 'adrianna.pinska+sutekh@gmail.com'),
     }
 
@@ -52,11 +58,12 @@ class SutekhInfo(object):
         PEOPLE['Adrianna'],
     ]
 
-    SOURCEFORGE_URL = 'http://sourceforge.net/projects/sutekh/'
-    PYPI_URL = 'http://pypi.python.org/pypi/Sutekh/'
+    SOURCEFORGE_URL = 'https://sourceforge.net/projects/sutekh/'
+    PYPI_URL = 'https://pypi.python.org/pypi/Sutekh/'
 
     LICENSE = 'GPL'
-    LICENSE_TEXT = resource_string(__name__, 'COPYING')
+    # resource_string returns bytes, because reasons
+    LICENSE_TEXT = resource_string(__name__, 'COPYING').decode('utf8')
 
     CLASSIFIERS = [
         'Development Status :: 4 - Beta',
@@ -65,13 +72,10 @@ class SutekhInfo(object):
         'Environment :: X11 Applications :: GTK',
         'Intended Audience :: Developers',
         'Intended Audience :: End Users/Desktop',
-        'License :: OSI Approved :: GNU General Public License (GPL)',
+        GPL,
         'Operating System :: Microsoft :: Windows',
         'Operating System :: POSIX',
-        'Programming Language :: Python :: 2.4',
-        'Programming Language :: Python :: 2.5',
-        'Programming Language :: Python :: 2.6',
-        'Programming Language :: Python :: 2.7',
+        'Programming Language :: Python :: 3.7',
         'Topic :: Games/Entertainment',
         'Topic :: Software Development :: Libraries :: Python Modules',
     ]
@@ -82,26 +86,23 @@ class SutekhInfo(object):
     ]
 
     INSTALL_REQUIRES = [
-        'SQLObject >= 0.9.0, < 1.7',  # fetching the dev version requires svn
-                           # (which is a bit crazy as an install requirement)
-        'PyProtocols',
+        'SQLObject >= 3.0.0',
         'ply',
         'configobj',
-        'simplejson',
+        'keyring',  # Needed to store the SecretLibrary password
     ]
 
     # Install these manually
     NON_EGG_REQUIREMENTS = [
         'setuptools',
-        'pysqlite',  # sqlite3 is installed by default in Python >= 2.5
-        'PyGTK',
+        'gobject-introspection',
     ]
 
     # Currently this allows us license the Windows build (which
     # includes dependencies) under the GPL version 2 (which
     # conveniently is the same license in Sutekh's COPYING
-    # file although Sutekh itself also later versions of the
-    # GPL).
+    # file although Sutekh itself also allows later versions
+    # of the GPL).
     #
     # dependency -> (
     #   license classifier,
@@ -110,48 +111,38 @@ class SutekhInfo(object):
     # )
     DEPENDENCY_LICENSES = {
         'SQLObject': (
-            'License :: OSI Approved :: GNU Library or Lesser '
-                'General Public License (LGPL)',
+            LGPL,
             'http://www.gnu.org/copyleft/lesser.html',
             'Version 3'),
-        'PyProtocols': (
-            'License :: OSI Approved :: Zope Public License',
-            'http://www.zope.org/Resources/ZPL',
-            'Version 2.1'),
         'ply': (
-            # Note: ply changes to BSD license in version 3.2
-            'License :: OSI Approved :: GNU Library or Lesser '
-                'General Public License (LGPL)',
-            'http://www.gnu.org/licenses/lgpl-2.1.html',
-            'Version 2.1'),
+            # Note: ply changed to a BSD license in version 3.2
+            # The license doesn't appear to be anywhere other than the readme,
+            # so we point to the readme for the 3.11 release.
+            'License :: OSI Approved :: BSD License',
+            'https://raw.githubusercontent.com/dabeaz/ply/0f398b72618c1564d71f7dc0558e6722b241875a/README.md',
+            'New-BSD license'),
         'configobj': (
             'License :: OSI Approved :: BSD License',
-            'http://www.voidspace.org.uk/python/configobj.html#license',
+            'https://raw.githubusercontent.com/DiffSK/configobj/master/LICENSE',
             'New-BSD license'),
-        'simplejson': (
-            'License :: OSI Approved :: MIT License',
-            'https://raw.githubusercontent.com/simplejson/simplejson/master/LICENSE.txt',
+        'keyring': (
+            MIT,
+            'https://raw.githubusercontent.com/jaraco/keyring/master/LICENSE',
             'MIT license'),
         'setuptools': (
-            'License :: OSI Approved :: Python Software Foundation License',
+            PYTHON,
             'http://www.python.org/psf/license/',
             'Version 2'),
-        'PyGTK': (
-            'License :: OSI Approved :: GNU Library or Lesser '
-                'General Public License (LGPL)',
+        'gibject-introspection': (
+            LGPL,
             'http://www.gnu.org/copyleft/lesser.html',
             'Version 2 or later'),
         'GTK': (
-            'License :: OSI Approved :: GNU Library or Lesser '
-                'General Public License (LGPL)',
+            LGPL,
             'http://www.gnu.org/copyleft/lesser.html',
             'Version 2 or later'),
         'Python': (
-            'License :: OSI Approved :: Python Software Foundation License',
+            PYTHON,
             'http://www.python.org/psf/license/',
             'Version 2'),
-        'ZipDLL': (  # NSIS Plugin
-            'License :: OSI Approved :: GNU General Public License (GPL)',
-            'http://www.gnu.org/copyleft/gpl.html',
-            'Version 2 or later'),
     }
