@@ -1,25 +1,25 @@
-# AboutDialog.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2007 Simon Cross <hodgestar@gmail.com>
 # GPL - see COPYING for details
 
 """Simple about dialog for Sutekh"""
 
+from gi.repository import Gtk
+
+from sutekh.base.Utility import get_database_url
+
 from sutekh.gui import SutekhIcon
 from sutekh.SutekhInfo import SutekhInfo
-import gtk
 
 
-# pylint: disable-msg=R0904
-# R0904 - gtk Widget, so has many public methods
-class SutekhAboutDialog(gtk.AboutDialog):
+class SutekhAboutDialog(Gtk.AboutDialog):
     """About dialog for Sutekh."""
+    # pylint: disable=too-many-public-methods
+    # Gtk Widget, so has many public methods
 
-    # pylint: disable-msg=W0142
-    # ** magic OK here
     def __init__(self, *aArgs, **kwargs):
-        super(SutekhAboutDialog, self).__init__(*aArgs, **kwargs)
+        super().__init__(*aArgs, **kwargs)
 
         self.set_name(SutekhInfo.NAME)
         self.set_version(SutekhInfo.VERSION_STR)
@@ -34,3 +34,8 @@ class SutekhAboutDialog(gtk.AboutDialog):
         self.set_artists([tAuth[0] for tAuth in SutekhInfo.ARTISTS])
         self.set_logo(SutekhIcon.SUTEKH_ICON)
         # self.set_translator_credits(translator_credits)
+        # pylint: disable=no-member
+        # pylint doesn't like the dialog vbox
+        oUrlText = Gtk.Label('Database URI: %s' % get_database_url())
+        self.vbox.pack_end(oUrlText, False, False, 0)
+        oUrlText.show()
