@@ -1,6 +1,5 @@
-# ClanDisciplineStats.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2007 Simon Cross <hodgestar@gmail.com>,
 # Copyright 2007 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
@@ -9,15 +8,15 @@
    spreads of the vampires in each.
    """
 
-import gtk
-import pango
-import gobject
+from gi.repository import GObject, Gtk, Pango
+
 from sqlobject import SQLObjectNotFound
-from sutekh.core.SutekhObjects import PhysicalCard, Clan, ICardType, \
-        AbstractCard, IKeyword
+from sutekh.base.core.BaseTables import PhysicalCard
+from sutekh.base.core.BaseAdapters import ICardType, IKeyword
+from sutekh.core.SutekhTables import Clan, SutekhAbstractCard
 from sutekh.gui.PluginManager import SutekhPlugin
-from sutekh.gui.SutekhDialog import SutekhDialog
-from sutekh.gui.AutoScrolledWindow import AutoScrolledWindow
+from sutekh.base.gui.SutekhDialog import SutekhDialog
+from sutekh.base.gui.AutoScrolledWindow import AutoScrolledWindow
 
 
 class ClanDisciplineStats(SutekhPlugin):
@@ -31,17 +30,38 @@ class ClanDisciplineStats(SutekhPlugin):
     dTableVersions = {}
     aModelsSupported = (PhysicalCard,)
 
-    # pylint: disable-msg=W0142
-    # **magic OK here
+    sMenuName = "Clan Discipline Stats"
+
+    sHelpCategory = "card_list:analysis"
+
+    sHelpText = """This shows an analysis of all the different clans in the
+                   White Wolf card list. For each clan, it displays the total
+                   number of vampires in the clan, the sum of the
+                   vampires&#8217; capacities, and the most common disciplines.
+                   It also shows the score for the disciplines, and various
+                   stats about how the disciplines are distributed.
+
+                   You can expand the tree view to show the details for each
+                   legal grouping combination.
+
+                   The score is intended to give you some indication of how
+                   common disciplines are within the clan. Vampires without
+                   a discipline score 0 for that discipline, vampires with
+                   the inferior discipline score 1 and vampires with the
+                   superior discipline score 2.
+
+                   Note that this will only include cards not legal for
+                   tournament play (such as banned cards or storyline only
+                   cards) if the current profile for the full card list shows
+                   those cards."""
+
     def __init__(self, *args, **kwargs):
-        super(ClanDisciplineStats, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._oStatsVbox = None
 
     def get_menu_item(self):
         """Register on the 'Analyze' menu"""
-        if not self.check_versions() or not self.check_model_type():
-            return None
-        oClanStats = gtk.MenuItem("Clan Discipline Stats")
+        oClanStats = Gtk.MenuItem(label=self.sMenuName)
         oClanStats.connect("activate", self.activate)
         return ('Analyze', oClanStats)
 
@@ -54,16 +74,16 @@ class ClanDisciplineStats(SutekhPlugin):
     def make_dialog(self):
         """Create the dialog to display the statistics"""
         oDlg = SutekhDialog("Clan Vampire Statistics", self.parent,
-                gtk.DIALOG_DESTROY_WITH_PARENT)
+                            Gtk.DialogFlags.DESTROY_WITH_PARENT)
 
-        oDlg.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
+        oDlg.add_button("_Close", Gtk.ResponseType.CLOSE)
         oDlg.connect("response", lambda oW, oR: oDlg.destroy())
 
-        self._oStatsVbox = gtk.VBox(False, 0)
+        self._oStatsVbox = Gtk.VBox(homogeneous=False, spacing=0)
 
-        # pylint: disable-msg=E1101
+        # pylint: disable=no-member
         # vbox methods not seen
-        oDlg.vbox.pack_start(self._oStatsVbox)
+        oDlg.vbox.pack_start(self._oStatsVbox, False, True, 0)
         oDlg.set_size_request(600, 400)
         oDlg.show_all()
 
@@ -80,11 +100,11 @@ class ClanDisciplineStats(SutekhPlugin):
         oView = StatsView(self.model.hideillegal)
 
         # top align, using viewport to scroll
-        self._oStatsVbox.pack_start(AutoScrolledWindow(oView, True))
+        self._oStatsVbox.pack_start(AutoScrolledWindow(oView), True, True, 0)
         self._oStatsVbox.show_all()
 
 
-class GroupStats(object):
+class GroupStats:
     """Manage statistics for a set of vampire groups."""
 
     def __init__(self):
@@ -114,14 +134,14 @@ class GroupStats(object):
     def top_n(self, iNum):
         """Return the iNum highest scoring stats"""
         aScores = [(oId, aStats[3]) for oId, aStats in
-                self.dDisciplines.items()]
+                   self.dDisciplines.items()]
         aScores.sort(key=lambda x: x[1])
         aScores.reverse()
         aScores = aScores[:iNum]
         return [self.dDisciplines[oId] for oId, _iScore in aScores]
 
 
-class ClanStats(object):
+class ClanStats:
     """Manage combined statistics for a clan"""
 
     def __init__(self, iMaxGrp):
@@ -140,9 +160,9 @@ class ClanStats(object):
                 oStats.add_vamp(oVamp)
 
 
-class StatsView(gtk.TreeView):
-    # pylint: disable-msg=R0904
-    # gtk classes, so we have lots of public methods
+class StatsView(Gtk.TreeView):
+    # pylint: disable=too-many-public-methods
+    # Gtk classes, so we have lots of public methods
     """TreeView used to display clan discipline stats"""
 
     def __init__(self, bHideIllegal):
@@ -152,30 +172,28 @@ class StatsView(gtk.TreeView):
             "# Sup / # Inf", "Score", "Score / Vamp", "Score / Total Cap.",
         ]
 
-        super(StatsView, self).__init__(self._oModel)
+        super().__init__(self._oModel)
 
-        oCell = gtk.CellRendererText()
-        oCell.set_property('style', pango.STYLE_ITALIC)
+        oCell = Gtk.CellRendererText()
+        oCell.set_property('style', Pango.Style.ITALIC)
 
         for iCol, sLabel in enumerate(self._aLabels):
-            oColumn = gtk.TreeViewColumn(sLabel, oCell, text=iCol)
+            oColumn = Gtk.TreeViewColumn(sLabel, oCell, text=iCol)
             oColumn.set_sort_column_id(iCol)
             self.append_column(oColumn)
 
-        self.set_grid_lines(gtk.TREE_VIEW_GRID_LINES_BOTH)
+        self.set_grid_lines(Gtk.TreeViewGridLine._BOTH)
 
 
-class StatsModel(gtk.TreeStore):
-    # pylint: disable-msg=R0904
-    # gtk classes, so we have lots of public methods
+class StatsModel(Gtk.TreeStore):
+    # pylint: disable=too-many-public-methods
+    # Gtk classes, so we have lots of public methods
     """TreeStore to hold the data about the clan statistics"""
 
     def __init__(self, bHideIllegal):
-        # pylint: disable-msg=W0142
-        # We need the * magic here
-        super(StatsModel, self).__init__(gobject.TYPE_STRING,
-                gobject.TYPE_STRING, gobject.TYPE_INT, gobject.TYPE_INT,
-                *[gobject.TYPE_STRING] * 5)
+        super().__init__(GObject.TYPE_STRING, GObject.TYPE_STRING,
+                         GObject.TYPE_INT, GObject.TYPE_INT,
+                         *[GObject.TYPE_STRING] * 5)
         self.oExcludedKeyword = None
         if bHideIllegal:
             try:
@@ -193,9 +211,9 @@ class StatsModel(gtk.TreeStore):
             oClanIter = self.append(None)
             self.set_iter_values(oClanIter, oClan, None, oClanStats.oAllStats)
 
-            # pylint: disable-msg=C0103
+            # pylint: disable=invalid-name
             # atGrps doesn't match the regexp, but is a valid name
-            atGrps = oClanStats.dSubStats.keys()
+            atGrps = list(oClanStats.dSubStats.keys())
             atGrps.sort()
 
             for tGrps in atGrps:
@@ -215,27 +233,28 @@ class StatsModel(gtk.TreeStore):
         sSupInfCnts = " ".join(["%d/%d" % (x[1], x[2]) for x in aTopN])
         sScores = " ".join([str(x[3]) for x in aTopN])
         sScoresPerVamp = " ".join(["%.2f" % (float(x[3]) / oGrpStats.iVamps)
-            for x in aTopN])
+                                   for x in aTopN])
         sScoresPerCap = " ".join(["%.2f" % (float(x[3]) /
-            oGrpStats.iTotalCapacity) for x in aTopN])
+                                            oGrpStats.iTotalCapacity)
+                                  for x in aTopN])
 
         self.set(oIter,
-            0, oClan.name,
-            1, sGrps,
-            2, oGrpStats.iVamps,
-            3, oGrpStats.iTotalCapacity,
-            4, sDisps,
-            5, sSupInfCnts,
-            6, sScores,
-            7, sScoresPerVamp,
-            8, sScoresPerCap,
-        )
+                 0, oClan.name,
+                 1, sGrps,
+                 2, oGrpStats.iVamps,
+                 3, oGrpStats.iTotalCapacity,
+                 4, sDisps,
+                 5, sSupInfCnts,
+                 6, sScores,
+                 7, sScoresPerVamp,
+                 8, sScoresPerCap,
+                )
 
     def gather_stats(self):
         """Collect up information on vampires from all clans."""
-        # pylint: disable-msg=E1101
-        # E1101 - avoid SQLObject method not detected problems
-        iMaxGrp = AbstractCard.select().max(AbstractCard.q.group)
+        # pylint: disable=no-member
+        # avoid SQLObject method not detected problems
+        iMaxGrp = SutekhAbstractCard.select().max(SutekhAbstractCard.q.group)
 
         aClans = list(Clan.select())
         aClans.sort(key=lambda x: x.name)
@@ -243,7 +262,7 @@ class StatsModel(gtk.TreeStore):
         for oClan in aClans:
             yield (oClan, self.gather_clan_stats(oClan, iMaxGrp))
 
-    # pylint: disable-msg=R0201
+    # pylint: disable=no-self-use
     # could be a function, but that doesn't add to clarity
     def gather_clan_stats(self, oClan, iMaxGrp):
         """Collect information on vampires from a particular clan."""
@@ -258,4 +277,5 @@ class StatsModel(gtk.TreeStore):
 
         return oClanStats
 
+
 plugin = ClanDisciplineStats
