@@ -1,21 +1,23 @@
-# ClusterCardList.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2006 Simon Cross <hodgestar@gmail.com>
 # GPL - see COPYING for details
 
 """Plugin to find clusters in the card lists."""
 
-import gtk
 import random
 import math
-from sutekh.core.SutekhObjects import PhysicalCard, \
-                                      PhysicalCardSet, \
-                                      IPhysicalCard
+
+from gi.repository import Gtk
+
+from sutekh.base.core.BaseTables import PhysicalCard, PhysicalCardSet
+from sutekh.base.core.BaseAdapters import IPhysicalCard
+from sutekh.base.core.CardSetUtilities import check_cs_exists
+from sutekh.base.gui.AutoScrolledWindow import AutoScrolledWindow
+from sutekh.base.gui.SutekhDialog import NotebookDialog, do_complaint_error
+
 from sutekh.core.CardListTabulator import CardListTabulator
 from sutekh.gui.PluginManager import SutekhPlugin
-from sutekh.gui.AutoScrolledWindow import AutoScrolledWindow
-from sutekh.gui.SutekhDialog import SutekhDialog, do_complaint_error
 
 
 class ClusterCardList(SutekhPlugin):
@@ -24,17 +26,15 @@ class ClusterCardList(SutekhPlugin):
        Allows the user to choose various clustering parameters, such as
        attributes to to use and methods, and then to create card sets
        from the clustering results."""
-    # pylint: disable-msg=R0902
+    # pylint: disable=too-many-instance-attributes
     # we use a lot of attributes to keep track of data & gui aspects
 
     dTableVersions = {}
     aModelsSupported = (PhysicalCard, PhysicalCardSet)
 
-    # pylint: disable-msg=W0142
-    # ** magic OK
     def __init__(self, *args, **kwargs):
-        super(ClusterCardList, self).__init__(*args, **kwargs)
-        # pylint: disable-msg=C0103
+        super().__init__(*args, **kwargs)
+        # pylint: disable=invalid-name
         # fMakeCardFromCluster triggers on length, but we like the name
         if not self.model:
             self._fMakeCardSetFromCluster = None
@@ -42,7 +42,6 @@ class ClusterCardList(SutekhPlugin):
         self._dPropButtons = {}
         self._dGroups = {}
         self._oResultsVbox = None
-        self._oNotebook = None
         self._aDistanceMeasureGroup = None
 
         # cluster parameter widgets
@@ -50,13 +49,9 @@ class ClusterCardList(SutekhPlugin):
         self._oNumClustersSpin = None
         self._oNumIterSpin = None
 
-    # pylint: enable-msg=W0142
-
     def get_menu_item(self):
         """Register on the 'Analyze' menu."""
-        if not self.check_versions() or not self.check_model_type():
-            return None
-        oCluster = gtk.MenuItem("Cluster Cards")
+        oCluster = Gtk.MenuItem(label="Cluster Cards")
         oCluster.connect("activate", self.activate)
         return ('Analyze', oCluster)
 
@@ -71,26 +66,25 @@ class ClusterCardList(SutekhPlugin):
 
         self._make_prop_groups()
 
-        oDlg = SutekhDialog(sDlgName, self.parent,
-                gtk.DIALOG_DESTROY_WITH_PARENT)
-        oDlg.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
-        oDlg.add_button(gtk.STOCK_EXECUTE, gtk.RESPONSE_APPLY)
+        oDlg = NotebookDialog(sDlgName, self.parent,
+                              Gtk.DialogFlags.DESTROY_WITH_PARENT)
+        oDlg.add_button("_Close", Gtk.ResponseType.CLOSE)
+        oBut = oDlg.add_button("Execute", Gtk.ResponseType.APPLY)
+        oImage = Gtk.Image.new_from_icon_name('system-run',
+                                              Gtk.IconSize.BUTTON)
+        oBut.set_image(oImage)
+        oBut.set_always_show_image(True)
 
         oDlg.connect("response", self.handle_response)
 
-        self._oNotebook = gtk.Notebook()
-
         oTableSection = self._make_table_section()
         oAlgorithmSection = self._make_algorithm_section()
         oResultsSection = self._make_results_section()
 
-        self._oNotebook.append_page(oTableSection, gtk.Label('Select Columns'))
-        self._oNotebook.append_page(oAlgorithmSection, gtk.Label('Settings'))
-        self._oNotebook.append_page(oResultsSection, gtk.Label('Results'))
+        oDlg.add_widget_page(oTableSection, 'Select Columns')
+        oDlg.add_widget_page(oAlgorithmSection, 'Settings')
+        oDlg.add_widget_page(oResultsSection, 'Results')
 
-        # pylint: disable-msg=E1101
-        # vbox confuses pylint
-        oDlg.vbox.pack_start(self._oNotebook)
         oDlg.show_all()
 
         return oDlg
@@ -100,22 +94,21 @@ class ClusterCardList(SutekhPlugin):
         dPropFuncs = CardListTabulator.get_default_prop_funcs()
         self._dGroups = {}
 
-        for sName, fProp in dPropFuncs.iteritems():
+        for sName, fProp in dPropFuncs.items():
             aParts = sName.split(":")
             if len(aParts) == 1:
                 self._dGroups.setdefault("Miscellaneous",
-                        {})[sName.capitalize()] = fProp
+                                         {})[sName.capitalize()] = fProp
             else:
-                sGroup, sRest = aParts[0].strip().capitalize(), \
-                        ":".join(aParts[1:]).strip().capitalize()
+                sGroup, sRest = (aParts[0].strip().capitalize(),
+                                 ":".join(aParts[1:]).strip().capitalize())
                 self._dGroups.setdefault(sGroup, {})[sRest] = fProp
 
     def _make_table_section(self):
         """Create a notebook, and populate the first tabe with a list of
            properties to cluster on."""
-        oNotebook = gtk.Notebook()
-        aGroups = self._dGroups.keys()
-        aGroups.sort()
+        oNotebook = Gtk.Notebook()
+        aGroups = sorted(self._dGroups.keys())
 
         self._dPropButtons = {}
 
@@ -123,27 +116,27 @@ class ClusterCardList(SutekhPlugin):
             self._dPropButtons[sGroup] = {}
             dPropFuncs = self._dGroups[sGroup]
 
-            oHbx = gtk.HBox(False, 0)
+            oHbx = Gtk.HBox(False, 0)
 
             iCols = 3
-            iPropsPerCol = len(dPropFuncs) / iCols
+            iPropsPerCol = len(dPropFuncs) // iCols
             if len(dPropFuncs) % iCols != 0:
                 iPropsPerCol += 1
 
-            aPropNames = dPropFuncs.keys()
-            aPropNames.sort()
+            aPropNames = sorted(dPropFuncs.keys())
 
             for iProp, sName in enumerate(aPropNames):
                 if iProp % iPropsPerCol == 0:
-                    oVbx = gtk.VBox(False, 0)
-                    oHbx.pack_start(oVbx)
+                    oVbx = Gtk.VBox(homogeneous=False, spacing=0)
+                    oHbx.pack_start(oVbx, False, True, 0)
 
-                oBut = gtk.CheckButton(sName)
-                oVbx.pack_start(oBut, False)  # pack at top, don't fill space
+                oBut = Gtk.CheckButton(sName)
+                # pack at top, don't expand
+                oVbx.pack_start(oBut, False, True, 0)
 
                 self._dPropButtons[sGroup][sName] = oBut
 
-            oNotebook.append_page(oHbx, gtk.Label(sGroup))
+            oNotebook.append_page(oHbx, Gtk.Label(sGroup))
 
         return oNotebook
 
@@ -151,40 +144,40 @@ class ClusterCardList(SutekhPlugin):
         """Populate a tab on the notebook with the parameters and options for
            the clustering algorithm.
            """
-        oVbx = gtk.VBox(False, 0)
+        oVbx = Gtk.VBox(homogeneous=False, spacing=0)
 
         # K-Means is the only clustering solution for the moment
-        oHeading = gtk.Label()
+        oHeading = Gtk.Label()
         oHeading.set_markup("<b>Parameters for K-Means Clustering</b>")
         oVbx.pack_start(oHeading, False, False, 5)  # top align
 
         # Number of iterations
-        oNumIterLabel = gtk.Label("Number of Iterations:")
-        self._oNumIterSpin = gtk.SpinButton()
+        oNumIterLabel = Gtk.Label(label="Number of Iterations:")
+        self._oNumIterSpin = Gtk.SpinButton()
         self._oNumIterSpin.set_range(1, 50)
         self._oNumIterSpin.set_increments(1, 10)
         self._oNumIterSpin.set_value(10)
-        oHbox = gtk.HBox(False, 0)
-        oHbox.pack_start(oNumIterLabel, False)  # left align
-        oHbox.pack_end(self._oNumIterSpin, False)  # right align
-        oVbx.pack_start(oHbox, False)
+        oHbox = Gtk.HBox(False, 0)
+        oHbox.pack_start(oNumIterLabel, False, True, 0)  # left align
+        oHbox.pack_end(self._oNumIterSpin, False, True, 0)  # right align
+        oVbx.pack_start(oHbox, False, True, 0)
 
         # Autoset Num clusters
-        self._oAutoNumClusters = gtk.CheckButton("One cluster per 80 cards")
-        oHbox = gtk.HBox(False, 0)
-        oHbox.pack_start(self._oAutoNumClusters, False)  # right align
-        oVbx.pack_start(oHbox, False)
+        self._oAutoNumClusters = Gtk.CheckButton("One cluster per 80 cards")
+        oHbox = Gtk.HBox(False, 0)
+        oHbox.pack_start(self._oAutoNumClusters, False, True, 0)  # right align
+        oVbx.pack_start(oHbox, False, True, 0)
 
         # Number of clusters
-        oNumClustersLabel = gtk.Label("Number of Clusters:")
-        self._oNumClustersSpin = gtk.SpinButton()
+        oNumClustersLabel = Gtk.Label(label="Number of Clusters:")
+        self._oNumClustersSpin = Gtk.SpinButton()
         self._oNumClustersSpin.set_range(2, 50)
         self._oNumClustersSpin.set_increments(1, 10)
         self._oNumClustersSpin.set_value(10)
-        oHbox = gtk.HBox(False, 0)
-        oHbox.pack_start(oNumClustersLabel, False)  # left align
-        oHbox.pack_end(self._oNumClustersSpin, False)  # right align
-        oVbx.pack_start(oHbox, False)
+        oHbox = Gtk.HBox(False, 0)
+        oHbox.pack_start(oNumClustersLabel, False, True, 0)  # left align
+        oHbox.pack_end(self._oNumClustersSpin, False, True, 0)  # right align
+        oVbx.pack_start(oHbox, False, True, 0)
 
         # Connect Autoset and Number of clusters
         self._oAutoNumClusters.set_active(True)
@@ -200,22 +193,22 @@ class ClusterCardList(SutekhPlugin):
         self._oAutoNumClusters.connect("toggled", auto_toggled)
 
         # Separator
-        oVbx.pack_start(gtk.HSeparator(), False, False, 10)
+        oVbx.pack_start(Gtk.HSeparator(), False, False, 10)
 
         # Distance Measure
-        oDistLabel = gtk.Label()
+        oDistLabel = Gtk.Label()
         oDistLabel.set_markup("<b>Distance Measure for Clustering</b>")
         oVbx.pack_start(oDistLabel, False, False, 5)
 
-        oIter = Vector.METRICS.iterkeys()
+        oIter = Vector.METRICS.keys()
         for sName in oIter:
-            oFirstBut = gtk.RadioButton(None, sName, False)
-            oVbx.pack_start(oFirstBut, False)
+            oFirstBut = Gtk.RadioButton(group=None, label=sName)
+            oVbx.pack_start(oFirstBut, False, True, 0)
             break
 
         for sName in oIter:
-            oBut = gtk.RadioButton(oFirstBut, sName)
-            oVbx.pack_start(oBut, False)
+            oBut = Gtk.RadioButton(group=oFirstBut, label=sName)
+            oVbx.pack_start(oBut, False, True, 0)
 
         self._aDistanceMeasureGroup = oFirstBut.get_group()
 
@@ -224,25 +217,25 @@ class ClusterCardList(SutekhPlugin):
     def _make_results_section(self):
         """Create a widget in the notebook which can be used to display
            the clustering results."""
-        oVbx = gtk.VBox(False, 0)
-        self._oResultsVbox = gtk.VBox(False, 0)
+        oVbx = Gtk.VBox(homogeneous=False, spacing=0)
+        self._oResultsVbox = Gtk.VBox(homogeneous=False, spacing=0)
 
         # Results Heading
-        oHeading = gtk.Label()
+        oHeading = Gtk.Label()
         oHeading.set_markup("<b>Results</b>")
-        oVbx.pack_start(oHeading, False)  # top align
+        oVbx.pack_start(oHeading, False, True, 0)  # top align
 
         # No Results Yet
-        oLabel = gtk.Label("No results yet.")
-        self._oResultsVbox.pack_start(oLabel)
-        oVbx.pack_start(self._oResultsVbox)
+        oLabel = Gtk.Label(label="No results yet.")
+        self._oResultsVbox.pack_start(oLabel, False, False, 0)
+        oVbx.pack_start(self._oResultsVbox, True, True, 0)
 
         return oVbx
 
-    # pylint: disable-msg=W0201, R0914
-    # W0201: We create a lot of attributes here, which is OK, because of
+    # pylint: disable=attribute-defined-outside-init, too-many-locals
+    # We create a lot of attributes here, which is OK, because of
     # plugin structure
-    # R0914: We use lots of local variables for clarity
+    # We use lots of local variables for clarity
     def _populate_results(self, aCards, aColNames, aMeans, aClusters):
         """Populate the results tab of the notebook with the results of
            clustering run."""
@@ -257,24 +250,24 @@ class ClusterCardList(SutekhPlugin):
         iHeaderRows = 1
         iExtraCols = 4
 
-        oTable = gtk.Table(rows=len(aMeans) + iHeaderRows,
-                columns=iExtraCols)
+        oTable = Gtk.Table(rows=len(aMeans) + iHeaderRows,
+                           columns=iExtraCols)
         oTable.set_row_spacings(0)
 
         # Headings
-        oLabel = gtk.Label()
+        oLabel = Gtk.Label()
         oLabel.set_markup('<b>Save Deck</b>')
         oTable.attach(oLabel, 0, 1, 0, 1, xpadding=3)
 
-        oLabel = gtk.Label()
+        oLabel = Gtk.Label()
         oLabel.set_markup('<b>Cluster Id</b>')
         oTable.attach(oLabel, 1, 2, 0, 1, xpadding=3)
 
-        oLabel = gtk.Label()
+        oLabel = Gtk.Label()
         oLabel.set_markup('<b>No. Cards</b>')
         oTable.attach(oLabel, 2, 3, 0, 1, xpadding=3)
 
-        oLabel = gtk.Label()
+        oLabel = Gtk.Label()
         oLabel.set_markup('<b>Cluster Center</b>')
         oTable.attach(oLabel, 3, 4, 0, 1, xpadding=3)
 
@@ -282,48 +275,50 @@ class ClusterCardList(SutekhPlugin):
         self._dCardSetMakingButtons = {}
         for iId, oMean in enumerate(self._aMeans):
             iRow = iId + iHeaderRows
-            oBut = gtk.CheckButton()
+            oBut = Gtk.CheckButton()
             self._dCardSetMakingButtons[iId] = oBut
             sCenterText = "\n".join([
                 "%s: %.2f" % (sColName, fColVal) for sColName, fColVal
                 in zip(aColNames, oMean)
                 if abs(fColVal) > 0.01
             ])
-            oCenterLabel = gtk.Label(sCenterText)
+            oCenterLabel = Gtk.Label(sCenterText)
             oCenterLabel.set_alignment(0.0, 0.5)
 
             oTable.attach(oBut, 0, 1, iRow, iRow + 1)
-            oTable.attach(gtk.Label(str(iId)), 1, 2, iRow, iRow + 1)
-            oTable.attach(gtk.Label(str(len(aClusters[iId]))),
-                2, 3, iRow, iRow + 1)
+            oTable.attach(Gtk.Label(str(iId)), 1, 2, iRow, iRow + 1)
+            oTable.attach(Gtk.Label(str(len(aClusters[iId]))),
+                          2, 3, iRow, iRow + 1)
             oTable.attach(oCenterLabel, 3, 4, iRow, iRow + 1)
 
         # top align, using viewport to scroll
-        self._oResultsVbox.pack_start(AutoScrolledWindow(oTable, True))
+        self._oResultsVbox.pack_start(AutoScrolledWindow(oTable),
+                                      True, True, 0)
 
-        oMakeCardSetsButton = gtk.Button("Make Card Sets from Selected"
-                " Clusters")
+        oMakeCardSetsButton = Gtk.Button("Make Card Sets from Selected"
+                                         " Clusters")
         oMakeCardSetsButton.connect("clicked", self.handle_make_card_sets)
-        self._oResultsVbox.pack_end(oMakeCardSetsButton, False)  # bottom align
+        # bottom align
+        self._oResultsVbox.pack_end(oMakeCardSetsButton, False, False, 0)
 
         self._oResultsVbox.show_all()
 
-    # pylint: enable-msg=W0201, R0914
+    # pylint: enable=attribute-defined-outside-init, too-many-locals
 
     # Actions
 
     def handle_response(self, oDlg, oResponse):
         """Handle the user's response to the options dialog."""
-        if oResponse == gtk.RESPONSE_CLOSE:
+        if oResponse == Gtk.ResponseType.CLOSE:
             oDlg.destroy()
-        elif oResponse == gtk.RESPONSE_APPLY:
+        elif oResponse == Gtk.ResponseType.APPLY:
             self.do_clustering()
             # change to results section
-            self._oNotebook.set_current_page(2)
+            oDlg.notebook.set_current_page(2)
 
     def handle_make_card_sets(self, _oSomeObj):
         """Create card a suitable card set from the chosen clusters"""
-        for iId, oBut in self._dCardSetMakingButtons.iteritems():
+        for iId, oBut in self._dCardSetMakingButtons.items():
             if oBut.get_active():
                 self._fMakeCardSetFromCluster(iId)
 
@@ -351,7 +346,7 @@ class ClusterCardList(SutekhPlugin):
 
             # iCard is defined because k_means doesn't call
             # this unless aCards is non-empty
-            # pylint: disable-msg=W0631
+            # pylint: disable=undefined-loop-variable
 
             if iCard == len(aCards):
                 # guard against slight possibility of being very close
@@ -377,18 +372,22 @@ class ClusterCardList(SutekhPlugin):
         for _iIter in range(iIterations):
             # empty clusters
             aClusters = []
-            for iClust in xrange(iNumClust):
+            for iClust in range(iNumClust):
                 aClusters.append([])
 
             # calculate membership in clusters
-            for iCard in xrange(iCards):
+            for iCard in range(iCards):
                 oVec = aCards[iCard]
-                iVmin = min(xrange(iNumClust),
-                    key=lambda iV: fDist(oVec, aMeans[iV]))
+                # pylint: disable=cell-var-from-loop
+                # Since we use key immediately, this warning isn't
+                # an issue
+                iVmin = min(range(iNumClust),
+                            key=lambda iV: fDist(oVec, aMeans[iV]))
+                # pylint: enable=cell-var-from-loop
                 aClusters[iVmin].append(iCard)
 
             # recompute the centroids
-            for iClust in xrange(iNumClust):
+            for iClust in range(iNumClust):
                 if aClusters[iClust]:
                     aMeans[iClust] = (1.0 / len(aClusters[iClust])) * sum(
                         (aCards[x] for x in aClusters[iClust])
@@ -403,15 +402,14 @@ class ClusterCardList(SutekhPlugin):
 
         # gather property functions
         dPropFuncs = {}
-        for sGroup, dButtons in self._dPropButtons.iteritems():
-            for sName, oBut in dButtons.iteritems():
+        for sGroup, dButtons in self._dPropButtons.items():
+            for sName, oBut in dButtons.items():
                 if oBut.get_active():
                     dPropFuncs[sGroup + ": " + sName] = \
-                            self._dGroups[sGroup][sName]
+                        self._dGroups[sGroup][sName]
 
         # sort column names
-        aColNames = dPropFuncs.keys()
-        aColNames.sort()
+        aColNames = sorted(dPropFuncs.keys())
 
         # make tabulator and get table
         oTab = CardListTabulator(aColNames, dPropFuncs)
@@ -435,7 +433,7 @@ class ClusterCardList(SutekhPlugin):
         # aClusters -> list of clusters, each cluster is a list of card indexes
 
         aMeans, aClusters = self.k_means(aTable, iNumClusts, iIterations,
-                fDist)
+                                         fDist)
 
         self._populate_results(aCards, aColNames, aMeans, aClusters)
 
@@ -444,24 +442,23 @@ class ClusterCardList(SutekhPlugin):
         sDeckName = '_cluster_deck_%d' % (iClusterId,)
 
         # Check Deck Doesn't Exist
-        if PhysicalCardSet.selectBy(name=sDeckName).count() != 0:
+        if check_cs_exists(sDeckName):
             do_complaint_error("Card Set %s already exists." %
-                    sDeckName)
+                               sDeckName)
             return
 
         # Create Deck
         oDeck = PhysicalCardSet(name=sDeckName)
 
-        # pylint: disable-msg=E1101
+        # pylint: disable=no-member
         # SQLObject confuses pylint
-        for iIndex in self._aClusters[iClusterId]:
-            oCard = IPhysicalCard(self._aCards[iIndex])
-            oDeck.addPhysicalCard(oCard)
-
-        self.open_cs(sDeckName, True)
+        aCards = [IPhysicalCard(self._aCards[x]) for x in
+                  self._aClusters[iClusterId]]
+        self._commit_cards(oDeck, aCards)
+        self._open_cs(sDeckName, True)
 
 
-class Vector(object):
+class Vector:
     """Really simple class representing a row of card table data."""
 
     METRICS = {}
@@ -470,7 +467,7 @@ class Vector(object):
         self._aData = aData
 
     # We do want to access _aData on other Vectors.
-    # pylint: disable-msg=W0212
+    # pylint: disable=protected-access
 
     def euclidian_distance(self, oVec2):
         """Euclidean distance between two vectors."""
