@@ -1,6 +1,5 @@
-# AbstractCardSetParser.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2006 Simon Cross <hodgestar@gmail.com>
 # Copyright 2006, 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
@@ -18,8 +17,8 @@
    into a PhysicalCardSet.
    """
 
-from sutekh.io.IOBase import BaseSutekhXMLParser
-from sutekh.core.SutekhObjects import MAX_ID_LENGTH
+from sutekh.io.BaseSutekhXMLParser import BaseSutekhXMLParser
+from sutekh.base.core.BaseTables import MAX_ID_LENGTH
 
 
 class AbstractCardSetParser(BaseSutekhXMLParser):
