@@ -10,21 +10,20 @@
 """Provide tools for locating and extracting data pack ZIP files."""
 
 import datetime
-import time
-import simplejson
-import urllib2
-import urlparse
+import json
+from urllib.error import URLError
+from urllib.parse import urljoin
 import socket
 
+from sutekh.base.io.UrlOps import urlopen_with_timeout
+
 DOC_URL = ('https://bitbucket.org/hodgestar/sutekh-datapack/raw/master/'
            'index.json')
 
 
 def parse_datapack_date(sDate):
     """Parse a datapack's ISO format date entry into a datetime object."""
-    sDate, _sMicro = sDate.split('.', 1)
-    # work around python 2.4 shortcomings
-    return datetime.datetime(*(time.strptime(sDate, "%Y-%m-%dT%H:%M:%S")[0:6]))
+    return datetime.datetime.strptime(sDate, "%Y-%m-%dT%H:%M:%S.%f")
 
 
 def find_all_data_packs(sTag, sDocUrl=DOC_URL, fErrorHandler=None):
@@ -50,32 +49,27 @@ def find_all_data_packs(sTag, sDocUrl=DOC_URL, fErrorHandler=None):
     "format-version": "1.0"
     }
     """
-    try:
-        oFile = urllib2.urlopen(sDocUrl)
-    except (urllib2.URLError, socket.timeout), oExp:
-        if fErrorHandler:
-            fErrorHandler(oExp)
-            oFile = None
-        else:
-            raise
-
+    oFile = urlopen_with_timeout(sDocUrl, fErrorHandler)
     if not oFile:
         return None, None, None
     try:
-        dIndex = simplejson.load(oFile)
-    except (urllib2.URLError, socket.timeout, ValueError), oExp:
+        dIndex = json.load(oFile)
+    except (URLError, socket.timeout, ValueError) as oExp:
         if fErrorHandler:
             fErrorHandler(oExp)
             return None, None, None
-        else:
-            raise
+        raise
+    finally:
+        # This is a basically a no-op for remote urls, but needed
+        # for when we're dealing with a local file
+        oFile.close()
     aZipUrls = []
     aHashes = []
     aDates = []
     for dPack in dIndex["datapacks"]:
         if dPack.get("tag") != sTag:
             continue
-        aZipUrls.append(urlparse.urljoin(sDocUrl, dPack["file"]))
+        aZipUrls.append(urljoin(sDocUrl, dPack["file"]))
         aHashes.append(dPack["sha256"])
         oDate = parse_datapack_date(dPack["updated_at"])
         aDates.append(oDate.strftime("%Y-%m-%d"))
@@ -96,7 +90,7 @@ def find_data_pack(sTag, sDocUrl=DOC_URL, fErrorHandler=None):
     if not aZipUrls:
         # No match
         return None, None
-    elif not aHashes:
+    if not aHashes:
         # No hash
         return aZipUrls[-1], None
     return aZipUrls[-1], aHashes[-1]
