@@ -1,6 +1,5 @@
-# ELDBDeckFileParser.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # ELDB Deck File Parser
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
@@ -11,7 +10,7 @@ from sutekh.core.ELDBUtilities import gen_name_lookups
 
 
 # State Classes
-class State(object):
+class State:
     """Base class for the State Objects."""
     def __init__(self, oHolder, dNameCache):
         self._sData = ""
@@ -63,9 +62,8 @@ class Description(State):
             self.data(sValue.strip('"'))
             self._oHolder.comment = self._sData
             return Cards(self._oHolder, self._dNameCache)
-        else:
-            self.data(sValue.strip('"') + '\n')
-            return self
+        self.data(sValue.strip('"') + '\n')
+        return self
 
 
 class Cards(State):
@@ -85,15 +83,15 @@ class Cards(State):
             sName = self._dNameCache[sCard]
         else:
             sName = sCard
-        self._oHolder.add(1, sName, None)
+        self._oHolder.add(1, sName, None, None)
         return self
 
 
-class ELDBDeckFileParser(object):
+class ELDBDeckFileParser:
     """Parser for the ELDB Deck format."""
 
     def __init__(self):
-        super(ELDBDeckFileParser, self).__init__()
+        super().__init__()
         self._dNameCache = gen_name_lookups()
         self._oState = None
 
