@@ -1,6 +1,5 @@
-# ELDBInventoryParser.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # ELDB Inventory Parser
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
@@ -10,7 +9,7 @@
 
 import re
 from sutekh.core.ELDBUtilities import gen_name_lookups
-from sutekh.io.IOBase import BaseLineParser
+from sutekh.base.io.IOBase import BaseLineParser
 
 
 class ELDBInventoryParser(BaseLineParser):
@@ -23,7 +22,7 @@ class ELDBInventoryParser(BaseLineParser):
     _oCardRe = re.compile(r'\s*"(?P<name>[^"]*)"\s*,\s*(?P<cnt>[0-9]+)')
 
     def __init__(self):
-        super(ELDBInventoryParser, self).__init__()
+        super().__init__()
         self._dNameCache = gen_name_lookups()
 
     def _feed(self, sLine, oHolder):
@@ -40,4 +39,4 @@ class ELDBInventoryParser(BaseLineParser):
                 sName = self._dNameCache[sName]
             if iCnt:
                 # ELDB will create 0 entries
-                oHolder.add(iCnt, sName, None)
+                oHolder.add(iCnt, sName, None, None)
