@@ -1,6 +1,5 @@
-# JOLDeckParser.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # JOL Deck File Parser
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
@@ -8,14 +7,14 @@
 """Parser for JOL deck format"""
 
 import re
-from sutekh.core.SutekhObjects import csv_to_canonical
-from sutekh.io.IOBase import BaseLineParser
+from sutekh.base.Utility import move_articles_to_front
+from sutekh.base.io.IOBase import BaseLineParser
 
 
 class JOLDeckParser(BaseLineParser):
     """Parser for the JOL Deck format."""
 
-    oCardLineRegexp = re.compile('((?P<num>[0-9]+)(\s)*x(\s)*)?(?P<name>.*)$')
+    oCardLineRegexp = re.compile(r'((?P<num>[0-9]+)(\s)*x(\s)*)?(?P<name>.*)$')
 
     def _feed(self, sLine, oHolder):
         """Read the line into the given CardSetHolder"""
@@ -34,6 +33,6 @@ class JOLDeckParser(BaseLineParser):
         if sName.endswith('(advanced)'):
             sName = sName.replace('(advanced)', '(Advanced)')
         # Avoid going down the exception path in IAbstractCard if we can
-        sName = csv_to_canonical(sName)
+        sName = move_articles_to_front(sName)
         # JOL has no expansion info
-        oHolder.add(iNum, sName, None)
+        oHolder.add(iNum, sName, None, None)
