@@ -1,6 +1,5 @@
-# PhysicalCardParser.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2005, 2006, 2007 Simon Cross <hodgestar@gmail.com>
 # Copyright 2007, 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
@@ -17,7 +16,7 @@
    into the default PhysicalCardSet 'My Collection'.
    """
 
-from sutekh.io.IOBase import BaseSutekhXMLParser
+from sutekh.io.BaseSutekhXMLParser import BaseSutekhXMLParser
 
 
 class PhysicalCardParser(BaseSutekhXMLParser):
@@ -30,10 +29,10 @@ class PhysicalCardParser(BaseSutekhXMLParser):
     sTypeTag = 'cards'
     sTypeName = 'Physical card list'
 
-    # pylint: disable-msg=R0201
+    # pylint: disable=no-self-use
 
     def _convert_tree(self, oHolder):
-        """parse the elementtree into a card set holder"""
+        """parse the Element Tree into a card set holder"""
         self._check_tree()
         oHolder.name = "My Collection"
         oRoot = self._oTree.getroot()
