@@ -1,6 +1,5 @@
-# WriteArdbText.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2008 Simon Cross <hodgestar@gmail.com>
 # GPL - see COPYING for details
 
@@ -35,15 +34,15 @@ class WriteArdbText(ArdbInfo):
     """Create a string in ARDB's text format representing a dictionary
        of cards."""
 
-    # pylint: disable-msg=R0201
+    # pylint: disable=no-self-use
     # method for consistency with the other methods
     def _gen_header(self, oHolder):
         """Generate an ARDB text file header."""
-        return "Deck Name : %s\n" \
-               "Author : %s\n" \
-               "Description :\n%s\n" % (oHolder.name, oHolder.author,
-                       oHolder.comment)
-    # pylint: enable-msg=R0201
+        return ("Deck Name : %s\n"
+                "Author : %s\n"
+                "Description :\n%s\n" % (oHolder.name, oHolder.author,
+                                         oHolder.comment))
+    # pylint: enable=no-self-use
 
     def _gen_crypt(self, dCards):
         """Generaten an ARDB text file crypt description.
@@ -64,41 +63,21 @@ class WriteArdbText(ArdbInfo):
         # so we need to keep track and format later
         iDiscJust = 0
         iTitleJust = 0
-        for oCard,  (iCount, _sSet) in sorted(dCombinedVamps.iteritems(),
-                key=lambda x: (-x[1][0], -max(x[0].capacity, x[0].life),
-                    x[0].name)):
-            # We sort inversely on count, then capacity and then normally by
-            # name
-            dLine = {'count': iCount}
-            if len(oCard.creed) > 0:
-                dLine['clan'] = "%s (Imbued)" % \
-                        [x.name for x in oCard.creed][0]
-                dLine['capacity'] = oCard.life
-            else:
-                dLine['clan'] = [x.name for x in oCard.clan][0]
-                if dLine['clan'].endswith('antitribu'):
-                    # ARDB doesn't truncate antitribu further
-                    dLine['clan'] = '!' + dLine['clan'].replace(' antitribu',
-                            '')
-                else:
-                    dLine['clan'] = dLine['clan'][:10]  # truncate if needed
-                dLine['capacity'] = oCard.capacity
-            dLine['name'] = oCard.name
-            dLine['adv'] = '   '
-            if oCard.level is not None:
-                dLine['name'] = dLine['name'].replace(' (Advanced)', '')
-                dLine['adv'] = 'Adv'
+        for oCard, (iCount, _sSet) in sorted(dCombinedVamps.items(),
+                                             key=self._crypt_sort_key):
+            dLine = self._format_crypt_line(oCard, iCount)
+            if dLine['clan'].endswith('antitribu'):
+                # ARDB doesn't truncate antitribu further
+                dLine['clan'] = '!' + dLine['clan'].replace(' antitribu',
+                                                            '')
+            elif 'Imbued' not in dLine['clan']:
+                dLine['clan'] = dLine['clan'][:10]  # truncate if needed
+
             dLine['name'] = dLine['name'].ljust(18)[:18]  # truncate if needed
             dLine['disc'] = self._gen_disciplines(oCard)
             iDiscJust = max(iDiscJust, len(dLine['disc']))
 
-            dLine['title'] = '   '
-            if len(oCard.title):
-                dLine['title'] = [oC.name for oC in oCard.title][0]
-                dLine['title'] = dLine['title'].replace('Independent with ',
-                        '')[:12]
-                iTitleJust = max(iTitleJust, len(dLine['title']))
-            dLine['group'] = int(oCard.group)
+            iTitleJust = max(iTitleJust, len(dLine['title']))
             aCryptLines.append(dLine)
 
         for dLine in aCryptLines:
@@ -116,34 +95,37 @@ class WriteArdbText(ArdbInfo):
            """
         (dLib, iLibSize) = self._extract_library(dCards)
         dCombinedLib = self._group_sets(dLib)
+        dTypes = self._group_types(dCombinedLib)
 
         sLib = "Library [%d cards]\n" \
             "------------------------------------------------------------\n" \
             % (iLibSize,)
 
-        dTypes = {}
-        for oCard, (iCount, sTypeString, _sSet) in dCombinedLib.iteritems():
-            if sTypeString not in dTypes:
-                dTypes[sTypeString] = {}
-            dTypes[sTypeString].setdefault(oCard, 0)
-            dTypes[sTypeString][oCard] += iCount
-
         for sTypeString in sorted(dTypes):
             dCards = dTypes[sTypeString]
             iTotal = sum(dCards.values())
 
-            sLib += "%s [%d]\n" % (sTypeString, iTotal)
+            if sTypeString == 'Master':
+                iTrifles = self._count_trifles(dLib)
+                if iTrifles > 1:
+                    sLib += "%s [%d] (%d trifles)\n" % (sTypeString,
+                                                        iTotal, iTrifles)
+                elif iTrifles == 1:
+                    sLib += "%s [%d] (%d trifle)\n" % (sTypeString,
+                                                       iTotal, iTrifles)
+                else:
+                    sLib += "%s [%d]\n" % (sTypeString, iTotal)
+            else:
+                sLib += "%s [%d]\n" % (sTypeString, iTotal)
 
-            for oCard, iCount in sorted(dCards.iteritems(),
-                    key=lambda x: x[0].name):
+            for oCard, iCount in sorted(dCards.items(),
+                                        key=lambda x: x[0].name):
                 sLib += " %dx %s\n" % (iCount, oCard.name)
 
             sLib += "\n"
 
         return sLib
 
-    # pylint: disable-msg=R0913
-    # we need all these arguments
     def write(self, fOut, oHolder):
         """Takes filename, deck details and a dictionary of cards, of the
            form dCard[(id, name, set)] = count and writes the file."""
@@ -156,5 +138,3 @@ class WriteArdbText(ArdbInfo):
         fOut.write(self._gen_crypt(dCards))
         fOut.write("\n")
         fOut.write(self._gen_library(dCards))
-
-    # pylint: enable-msg=R0913
