@@ -1,6 +1,5 @@
-# WriteELDBDeckFile.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2008 Simon Cross <hodgestar@gmail.com>
 # GPL - see COPYING for details
 
@@ -23,27 +22,28 @@
    """
 
 from sutekh.core.ELDBUtilities import norm_name
+from sutekh.SutekhUtility import is_crypt_card
 
-class WriteELDBDeckFile(object):
+
+class WriteELDBDeckFile:
     """Create a string in ELDB deck format representing a card set."""
 
-    # pylint: disable-msg=R0201
+    # pylint: disable=no-self-use
     # method for consistency with the other methods
-    def _gen_header(self, oCardSet):
+    def _gen_header(self, oHolder):
         """Generate an ELDB deck file header."""
         return '"%s"\n' \
                '"%s"\n' \
-               '"%s"\n' % (oCardSet.name, oCardSet.author, oCardSet.comment)
+               '"%s"\n' % (oHolder.name, oHolder.author, oHolder.comment)
 
-    def _gen_inv(self, oCardSet):
+    def _gen_inv(self, oHolder):
         """Process the card set, creating the lines as needed"""
         aCrypt = []
         aLib = []
-        for oCard in oCardSet.cards:
+        for oCard in oHolder.cards:
             oAbsCard = oCard.abstractCard
-            sType = list(oAbsCard.cardtype)[0].name
             sName = norm_name(oAbsCard)
-            if sType == "Vampire" or sType == "Imbued":
+            if is_crypt_card(oAbsCard):
                 aCrypt.append(sName)
             else:
                 aLib.append(sName)
@@ -57,10 +57,10 @@ class WriteELDBDeckFile(object):
             sResult += '"%s"\n' % sName
         return sResult
 
-    # pylint: enable-msg=R0201
+    # pylint: enable=no-self-use
 
-    def write(self, fOut, oCardSet):
+    def write(self, fOut, oHolder):
         """Takes file object + card set to write, and writes an ELDB inventory
            representing the deck"""
-        fOut.write(self._gen_header(oCardSet))
-        fOut.write(self._gen_inv(oCardSet))
+        fOut.write(self._gen_header(oHolder))
+        fOut.write(self._gen_inv(oHolder))
