@@ -1,6 +1,5 @@
-# WriteJOL.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
 
@@ -18,10 +17,15 @@
 
    """
 
-class WriteJOL(object):
+from sutekh.base.core.BaseAdapters import IAbstractCard
+from sutekh.core.ELDBUtilities import type_of_card
+from sutekh.SutekhUtility import strip_group_from_name
+
+
+class WriteJOL:
     """Create a string in JOL format representing a card set."""
 
-    # pylint: disable-msg=R0201
+    # pylint: disable=no-self-use
     # method for consistency with the other methods
 
     def _escape(self, sName):
@@ -29,22 +33,17 @@ class WriteJOL(object):
         sName = sName.replace('(Advanced)', '(advanced)')
         return sName
 
-    def _crypt_or_library(self, oCard):
-        """Return 'crypt' or 'library' as required"""
-        sType = list(oCard.abstractCard.cardtype)[0].name
-        if sType == "Vampire" or sType == "Imbued":
-            return "crypt"
-        else:
-            return "library"
-
-    # pylint: enable-msg=R0201
-    def _gen_inv(self, oCardSet):
+    # pylint: enable=no-self-use
+    def _gen_inv(self, oHolder):
         """Process the card set, creating the lines as needed"""
-        dCards = {'crypt' : {}, 'library' : {}}
+        dCards = {'Crypt': {}, 'Library': {}}
         sResult = ""
-        for oCard in oCardSet.cards:
-            sType = self._crypt_or_library(oCard)
-            sName = self._escape(oCard.abstractCard.name)
+        for oCard in oHolder.cards:
+            oAbsCard = IAbstractCard(oCard)
+            sType = type_of_card(oAbsCard)
+            # FIXME: JOL will presumably add support for multi-group
+            # cards at some point, so we will need to change this.
+            sName = self._escape(strip_group_from_name(oAbsCard.name))
             dCards[sType].setdefault(sName, 0)
             dCards[sType][sName] += 1
         # Sort the output
@@ -54,14 +53,14 @@ class WriteJOL(object):
                     sResult += '%dx%s\n' % (iNum, sName)
                 else:
                     sResult += '%s\n' % sName
-            if sType == 'crypt':
+            if sType == 'Crypt':
                 sResult += '\n'
         # Assume conversion will be handled by viewers/editor/web browser?
         return sResult
 
-    # pylint: enable-msg=R0201
+    # pylint: enable=no-self-use
 
-    def write(self, fOut, oCardSet):
+    def write(self, fOut, oHolder):
         """Takes file object + card set to write, and writes an JOL deck
            representing the deck"""
-        fOut.write(self._gen_inv(oCardSet))
+        fOut.write(self._gen_inv(oHolder))
