@@ -1,6 +1,5 @@
-# XmlFileHandling.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2007 Simon Cross <hodgestar@gmail.com>,
 # Copyright 2007, 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
@@ -10,38 +9,37 @@
 
 """Routines for manipulating XML Files"""
 
-from sutekh.core.SutekhObjects import PhysicalCardSet, IPhysicalCardSet
-from sutekh.core.CardSetHolder import CardSetHolder, CardSetWrapper
-from sutekh.core.CardLookup import DEFAULT_LOOKUP
-from sutekh.SutekhUtility import gen_temp_file, gen_temp_dir, safe_filename
+import os
+
+from sqlobject import SQLObjectNotFound
+
+from sutekh.base.Utility import gen_temp_file, safe_filename
+from sutekh.base.core.BaseTables import PhysicalCardSet
+from sutekh.base.core.BaseAdapters import IPhysicalCardSet
+from sutekh.base.core.CardSetHolder import CardSetHolder, CardSetWrapper
+from sutekh.base.core.CardLookup import DEFAULT_LOOKUP
+
 from sutekh.io.PhysicalCardParser import PhysicalCardParser
 from sutekh.io.PhysicalCardSetParser import PhysicalCardSetParser
 from sutekh.io.AbstractCardSetParser import AbstractCardSetParser
 from sutekh.io.PhysicalCardSetWriter import PhysicalCardSetWriter
-from sqlobject import SQLObjectNotFound
-import os
 
 
 def _do_read(oParser, sFileName, oLookup, bIgnoreWarnings):
     """Helper function to read from a parser"""
     oHolder = CardSetHolder()
-    oParser.parse(file(sFileName, 'rU'), oHolder)
+    oParser.parse(open(sFileName, 'r'), oHolder)
     oHolder.create_pcs(oLookup)
     if not bIgnoreWarnings:
         return oHolder.get_warnings()
     return None
 
 
-class PhysicalCardXmlFile(object):
+class PhysicalCardXmlFile:
     """Class for handling PhysicalCard XML Files"""
-    def __init__(self, sFileName=None, sDir=None, oLookup=DEFAULT_LOOKUP):
+    def __init__(self, sFileName=None, oLookup=DEFAULT_LOOKUP):
         self.oCardLookup = oLookup
-        if sFileName is not None:
-            self.sXmlFile = sFileName
-        else:
-            if sDir is None:
-                sDir = gen_temp_dir()
-            self.sXmlFile = gen_temp_file('physical_cards_', sDir)
+        self.sXmlFile = sFileName
 
     def read(self, bIgnoreWarnings=True):
         """Read the card collection from the file"""
@@ -49,14 +47,14 @@ class PhysicalCardXmlFile(object):
             raise IOError("No Filename specified")
         oParser = PhysicalCardParser()
         return _do_read(oParser, self.sXmlFile, self.oCardLookup,
-                bIgnoreWarnings)
+                        bIgnoreWarnings)
 
-    # pylint: disable-msg=R0201
+    # pylint: disable=no-self-use
     # method for backwards compatibility
     def write(self):
         """Write the card collection to the file (DEPRECATED)."""
         raise RuntimeError("Writing out of physical card lists to XML files"
-                " is no longer supported.")
+                           " is no longer supported.")
 
     def delete(self):
         """Delete the file"""
@@ -65,7 +63,7 @@ class PhysicalCardXmlFile(object):
         os.remove(self.sXmlFile)
 
 
-class AbstractCardSetXmlFile(object):
+class AbstractCardSetXmlFile:
     """Class for handling Abstract Card Set XML files"""
     def __init__(self, sFileName=None, oLookup=DEFAULT_LOOKUP):
         self.oCardLookup = oLookup
@@ -77,14 +75,14 @@ class AbstractCardSetXmlFile(object):
             raise IOError("No Filename specified")
         oParser = AbstractCardSetParser()
         return _do_read(oParser, self.sXmlFile, self.oCardLookup,
-                bIgnoreWarnings)
+                        bIgnoreWarnings)
 
-    # pylint: disable-msg=R0201
+    # pylint: disable=no-self-use
     # method for backwards compatibility
     def write(self, _sAbstractCardSetName):
         """Write the given card set to the file (DEPRECATED)."""
         raise RuntimeError("Writing out of abstract card sets to XML files"
-                " is no longer supported.")
+                           " is no longer supported.")
 
     def delete(self):
         """Delete the file"""
@@ -93,7 +91,7 @@ class AbstractCardSetXmlFile(object):
         os.remove(self.sXmlFile)
 
 
-class PhysicalCardSetXmlFile(object):
+class PhysicalCardSetXmlFile:
     """Class for handling Physical Card Set XML files"""
     def __init__(self, sFileName=None, oLookup=DEFAULT_LOOKUP):
         self.oCardLookup = oLookup
@@ -105,23 +103,24 @@ class PhysicalCardSetXmlFile(object):
             raise IOError("No Filename specified")
         oParser = PhysicalCardSetParser()
         return _do_read(oParser, self.sXmlFile, self.oCardLookup,
-                bIgnoreWarnings)
+                        bIgnoreWarnings)
 
-    def write(self, sPhysicalCardSetName):
+    def write(self, sPCSName):
         """Write the given card set to the file"""
         oWriter = PhysicalCardSetWriter()
         if self.sXmlFile is None:
-            sFileName = safe_filename(sPhysicalCardSetName)
-            fOut = file(sFileName, 'w')
+            sFileName = safe_filename(sPCSName) + '.xml'
         else:
-            fOut = file(self.sXmlFile, 'w')
+            sFileName = self.sXmlFile
+        fOut = open(sFileName, 'w')
         try:
-            oPCS = IPhysicalCardSet(sPhysicalCardSetName)
-        except SQLObjectNotFound:
-            raise IOError('No card set named %s ' % sPhysicalCardSetName)
+            oPCS = IPhysicalCardSet(sPCSName)
+        except SQLObjectNotFound as oExp:
+            raise IOError(f'No card set named {sPCSName}') from oExp
         oHolder = CardSetWrapper(oPCS)
         oWriter.write(fOut, oHolder)
         fOut.close()
+        return sFileName
 
     def delete(self):
         """Delete the file"""
