@@ -1,21 +1,22 @@
-# test_CardSetManagementModel.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
 
 """Tests the Card Set Management Model"""
 
+from gi.repository import Gtk
+
 from sutekh.tests.TestCore import SutekhTest
-from sutekh.core.SutekhObjects import PhysicalCardSet
-from sutekh.core import Filters
-from sutekh.gui.CardSetManagementModel import CardSetManagementModel
+from sutekh.base.core.BaseTables import PhysicalCardSet
+from sutekh.base.core import BaseFilters
+from sutekh.base.gui.CardSetManagementModel import CardSetManagementModel
 
 
-class DummyWindow(object):
+class DummyWindow:
     """Dummy main window object"""
 
-    # pylint: disable-msg=R0201
+    # pylint: disable=no-self-use
     # Must be a method to act as dummy
     def find_pane_by_name(self, sName):
         """Proxy for the find_pane_by_name method"""
@@ -30,6 +31,8 @@ class DummyWindow(object):
 
 class CardSetManagementModelTests(SutekhTest):
     """Class for the test cases"""
+    # pylint: disable=too-many-public-methods
+    # unittest.TestCase, so many public methods
 
     def test_basic(self):
         """Test the basic functionality"""
@@ -51,42 +54,51 @@ class CardSetManagementModelTests(SutekhTest):
         # expected failure
         self.assertEqual(oModel.get_path_from_name('aaffr'), None)
         # Test model structure
-        self.assertEqual(oModel.get_path_from_name('Root'), (0,))
-        self.assertEqual(oModel.get_path_from_name('Sib'), (1,))
-        self.assertEqual(oModel.get_path_from_name('Child'), (0, 0))
-        self.assertEqual(oModel.get_path_from_name('Child 2 Branch'), (0, 1))
-        self.assertEqual(oModel.get_path_from_name('Card Set 1'), (0, 0, 1))
-        self.assertEqual(oModel.get_path_from_name('Card Set 3'), (0, 0, 3))
+        self.assertEqual(oModel.get_path_from_name('Root'), Gtk.TreePath("0"))
+        self.assertEqual(oModel.get_path_from_name('Sib'), Gtk.TreePath("1"))
+        self.assertEqual(oModel.get_path_from_name('Child'),
+                         Gtk.TreePath("0:0"))
+        self.assertEqual(oModel.get_path_from_name('Child 2 Branch'),
+                         Gtk.TreePath("0:1"))
+        self.assertEqual(oModel.get_path_from_name('Card Set 1'),
+                         Gtk.TreePath("0:0:1"))
+        self.assertEqual(oModel.get_path_from_name('Card Set 3'),
+                         Gtk.TreePath("0:0:3"))
         self.assertEqual(oModel.get_path_from_name('Child 2 Card Set 0'),
-                (0, 1, 0))
+                         Gtk.TreePath("0:1:0"))
         # Test filtering
-        oFilter = Filters.CardSetNameFilter('Child 2')
+        oFilter = BaseFilters.CardSetNameFilter('Child 2')
         self.assertEqual(oModel.get_card_set_iterator(oFilter).count(), 3)
         oModel.selectfilter = oFilter
         oModel.applyfilter = True
         oModel.load()
         # Test that tree is there, with parents retained
-        self.assertEqual(oModel.get_path_from_name('Root'), (0,))
+        self.assertEqual(oModel.get_path_from_name('Root'), Gtk.TreePath("0"))
         self.assertEqual(oModel.get_path_from_name('Sib'), None)
-        self.assertEqual(oModel.get_path_from_name('Child 2 Branch'), (0, 0))
+        self.assertEqual(oModel.get_path_from_name('Child 2 Branch'),
+                         Gtk.TreePath("0:0"))
         self.assertEqual(oModel.get_path_from_name('Child 2 Card Set 0'),
-                (0, 0, 0))
+                         Gtk.TreePath("0:0:0"))
         oModel.applyfilter = False
         oModel.load()
         # Test that tree is restored
-        self.assertEqual(oModel.get_path_from_name('Root'), (0,))
-        self.assertEqual(oModel.get_path_from_name('Sib'), (1,))
-        self.assertEqual(oModel.get_path_from_name('Child'), (0, 0))
-        self.assertEqual(oModel.get_path_from_name('Child 2 Branch'), (0, 1))
-        self.assertEqual(oModel.get_path_from_name('Card Set 1'), (0, 0, 1))
+        self.assertEqual(oModel.get_path_from_name('Root'), Gtk.TreePath("0"))
+        self.assertEqual(oModel.get_path_from_name('Sib'), Gtk.TreePath("1"))
+        self.assertEqual(oModel.get_path_from_name('Child'),
+                         Gtk.TreePath("0:0"))
+        self.assertEqual(oModel.get_path_from_name('Child 2 Branch'),
+                         Gtk.TreePath("0:1"))
+        self.assertEqual(oModel.get_path_from_name('Card Set 1'),
+                         Gtk.TreePath("0:0:1"))
 
-        oFilter = Filters.CardSetNameFilter('Child 2 Branch')
+        oFilter = BaseFilters.CardSetNameFilter('Child 2 Branch')
         self.assertEqual(oModel.get_card_set_iterator(oFilter).count(), 1)
         oModel.selectfilter = oFilter
         oModel.applyfilter = True
         oModel.load()
         # test filter results
-        self.assertEqual(oModel.get_path_from_name('Root'), (0,))
+        self.assertEqual(oModel.get_path_from_name('Root'), Gtk.TreePath("0"))
         self.assertEqual(oModel.get_path_from_name('Sib'), None)
-        self.assertEqual(oModel.get_path_from_name('Child 2 Branch'), (0, 0))
+        self.assertEqual(oModel.get_path_from_name('Child 2 Branch'),
+                         Gtk.TreePath("0:0"))
         self.assertEqual(oModel.get_path_from_name('Child 2 Card Set 0'), None)
