@@ -1,14 +1,14 @@
-# test_ARDBTextParser.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2007 Simon Cross <hodgestar@gmail.com>
 # GPL - see COPYING for details
 
 """Test case for ARDB text parser"""
 
+import unittest
+
 from sutekh.io.ARDBTextParser import ARDBTextParser
 from sutekh.tests.TestCore import SutekhTest
-import unittest
 
 ARDB_TEXT_EXAMPLE_1 = """
 Deck Name : Test Deck
@@ -86,47 +86,71 @@ Reaction [1]
 ...
 """
 
+ARDB_TEXT_EXAMPLE_4 = """
+Deck Name : Test Deck 4
+Created By: Anon Y Mous
+
+Crypt: (5 vampires, Min: 2, Max: 10 Ave: 7.33)
+------------------------------------------------------------
+2x Aaron Bathurst 4 for obf pot Nosferatu antitribu:4
+1x Aaron Duggan, Cameron's Toady 2 obt Lasombra:2
+1x Enkidu, the noah 11 ANI CEL OBF POT PRO for !Gangrel:4
+1x Hektor 9 CEL POT PRE QUI for priscus !Brujah:4
+...
+
+Library [6 cards]
+------------------------------------------------------------
+Action [6]
+2 x Test Card 1
+4 x Test Card 2
+...
+"""
+
+
 
 class ARDBTextParserTests(SutekhTest):
     """class for the ARDB/FELDB text input parser"""
+    # pylint: disable=too-many-public-methods
+    # unittest.TestCase, so many public methods
 
     def test_basic(self):
         """Run the input test."""
+        self.maxDiff = None
         oParser = ARDBTextParser()
         oHolder = self._make_holder_from_string(oParser, ARDB_TEXT_EXAMPLE_1)
 
         self.assertEqual(oHolder.name, "Test Deck")
         self.assertEqual(oHolder.author, "Anon Y Mous")
-        self.failUnless(oHolder.comment.startswith(
+        self.assertTrue(oHolder.comment.startswith(
             "    Simple test deck."))
-        self.failUnless(oHolder.comment.endswith("in/description\n\n"))
+        self.assertTrue(oHolder.comment.endswith("in/description\n\n"))
 
         aCards = oHolder.get_cards()
 
         self.assertEqual(len(aCards), 6)
-        self.failUnless(("Test Vamp 1", 2) in aCards)
-        self.failUnless(("Test Vamp 2", 1) in aCards)
-        self.failUnless(("Test Card 1", 2) in aCards)
-        self.failUnless(("Test Card 2", 4) in aCards)
-        self.failUnless(("Test Card 3", 12) in aCards)
-        self.failUnless(("Test Card 4", 1) in aCards)
+        self.assertTrue(("Test Vamp 1", 2) in aCards)
+        self.assertTrue(("Test Vamp 2", 1) in aCards)
+        self.assertTrue(("Test Card 1", 2) in aCards)
+        self.assertTrue(("Test Card 2", 4) in aCards)
+        self.assertTrue(("Test Card 3", 12) in aCards)
+        self.assertTrue(("Test Card 4", 1) in aCards)
 
         oHolder = self._make_holder_from_string(oParser, ARDB_TEXT_EXAMPLE_2)
 
         self.assertEqual(oHolder.name, "Test Deck 2")
         self.assertEqual(oHolder.author, "Anon Y Mous")
-        self.failUnless(oHolder.comment.startswith(
+        self.assertTrue(oHolder.comment.startswith(
             "Simple test deck."))
 
         aCards = oHolder.get_cards()
 
         self.assertEqual(len(aCards), 6)
-        self.failUnless(("Test Vamp 1", 2) in aCards)
-        self.failUnless(("Test Vamp 2", 1) in aCards)
-        self.failUnless(("Test Card 1", 2) in aCards)
-        self.failUnless(("Test Card 2", 4) in aCards)
-        self.failUnless(("Test Card 3", 12) in aCards)
-        self.failUnless(("Test Card 4", 1) in aCards)
+        self.assertTrue(("Test Vamp 1", 2) in aCards)
+        self.assertTrue(("Test Vamp 2", 1) in aCards)
+        self.assertTrue(("Test Card 1", 2) in aCards)
+        self.assertTrue(("Test Card 2", 4) in aCards)
+        self.assertTrue(("Test Card 3", 12) in aCards)
+        self.assertTrue(("Test Card 4", 1) in aCards)
 
         oHolder = self._make_holder_from_string(oParser, ARDB_TEXT_EXAMPLE_3)
 
@@ -136,13 +160,27 @@ class ARDBTextParserTests(SutekhTest):
         aCards = oHolder.get_cards()
 
         self.assertEqual(len(aCards), 6)
-        self.failUnless(("Test Vamp 1", 2) in aCards)
-        self.failUnless(("Test Vamp 2", 1) in aCards)
-        self.failUnless(("Test Card 1", 2) in aCards)
-        self.failUnless(("Test Card 2", 4) in aCards)
-        self.failUnless(("Test Card 3", 12) in aCards)
-        self.failUnless(("Test Card 4", 1) in aCards)
+        self.assertTrue(("Test Vamp 1", 2) in aCards)
+        self.assertTrue(("Test Vamp 2", 1) in aCards)
+        self.assertTrue(("Test Card 1", 2) in aCards)
+        self.assertTrue(("Test Card 2", 4) in aCards)
+        self.assertTrue(("Test Card 3", 12) in aCards)
+        self.assertTrue(("Test Card 4", 1) in aCards)
+
+        oHolder = self._make_holder_from_string(oParser, ARDB_TEXT_EXAMPLE_4)
+
+        self.assertEqual(oHolder.name, "Test Deck 4")
+        self.assertEqual(oHolder.author, "Anon Y Mous")
+
+        aCards = oHolder.get_cards()
+
+        self.assertTrue(("Hektor (Group 4)", 1) in aCards)
+        self.assertTrue(("Enkidu, The Noah (Group 4)", 1) in aCards)
+        self.assertTrue(("Aaron Bathurst (Group 4)", 2) in aCards)
+        self.assertTrue(("Aaron Duggan, Cameron's Toady (Group 2)", 1) in aCards)
+        self.assertTrue(("Test Card 1", 2) in aCards)
+        self.assertTrue(("Test Card 2", 4) in aCards)
 
 
 if __name__ == "__main__":
-    unittest.main()
+    unittest.main()  # pragma: no cover
