@@ -5,14 +5,16 @@
 
 """Test the Data Pack utilities"""
 
-import simplejson
-import urllib
+import json
 import unittest
-import urlparse
+
+from urllib.parse import urljoin
+from urllib.request import pathname2url
+
 from sutekh.tests.TestCore import SutekhTest
 from sutekh.io.DataPack import find_data_pack, find_all_data_packs
 
-TEST_DATA = simplejson.dumps({
+TEST_DATA = json.dumps({
     "datapacks": [
         {
             "description": ("Zip file of starter decks from Sabbat War to"
@@ -49,21 +51,10 @@ TEST_DATA = simplejson.dumps({
 })
 
 
-class FailFile(object):
-    """File'ish that raises exceptions for checking the error handler stuff"""
-
-    def __init__(self, oExp):
-        self._oExp = oExp
-
-    def read(self):
-        """Dummy method"""
-        raise self._oExp
-
-
 class DataPackTest(SutekhTest):
     """Class for the data pack tests"""
-    # pylint: disable-msg=R0904
-    # R0904 - unittest.TestCase, so many public methods
+    # pylint: disable=too-many-public-methods
+    # unittest.TestCase, so many public methods
 
     def create_index(self, sData):
         """Create a test index and return a URL for it."""
@@ -71,23 +62,24 @@ class DataPackTest(SutekhTest):
         fFile = open(sTempFileName, 'w')
         fFile.write(sData)
         fFile.close()
-        sTempUrl = 'file://%s' % urllib.pathname2url(sTempFileName)
+        sTempUrl = 'file://%s' % pathname2url(sTempFileName)
         return sTempUrl
 
     def test_find_data_pack(self):
         """Test finding data pack in sane documentation page"""
+        self.maxDiff = None
         sTempUrl = self.create_index(TEST_DATA)
 
         sUrl, sHash = find_data_pack('starters', sTempUrl)
 
-        self.assertEqual(sUrl, urlparse.urljoin(
+        self.assertEqual(sUrl, urljoin(
             sTempUrl, "Starters/Starters_SW_to_HttB.zip"))
 
         self.assertEqual(sHash, 'aaabb')
 
         sUrl, sHash = find_data_pack('rulebooks', sTempUrl)
 
-        self.assertEqual(sUrl, urlparse.urljoin(
+        self.assertEqual(sUrl, urljoin(
             sTempUrl, "Rulebooks/Rulebooks.zip"))
 
         self.assertEqual(sHash, 'dddeee')
@@ -101,29 +93,34 @@ class DataPackTest(SutekhTest):
         self.assertEqual('2013-12-10', aDates[0])
         self.assertEqual('2013-12-20', aDates[1])
 
-        self.assertEqual(aUrls[0], urlparse.urljoin(
+        self.assertEqual(aUrls[0], urljoin(
             sTempUrl, "TWD/TWDA_2009.zip"))
-        self.assertEqual(aUrls[1], urlparse.urljoin(
+        self.assertEqual(aUrls[1], urljoin(
             sTempUrl, "TWD/TWDA_2010.zip"))
         self.assertEqual(aHashes[0], 'a')
         self.assertEqual(aHashes[1], 'b')
 
         sUrl, sHash = find_data_pack('twd', sTempUrl)
         # We return the last one in this case
-        self.assertEqual(sUrl, urlparse.urljoin(
+        self.assertEqual(sUrl, urljoin(
             sTempUrl, "TWD/TWDA_2010.zip"))
         self.assertEqual(sHash, 'b')
 
     def test_error_handler_bad_index(self):
         """Test error handling for badly formatted index files."""
+        self.maxDiff = None
         sTempUrl = self.create_index("""Not JSON""")
         aErrors = []
 
-        sUrl, sHash = find_data_pack('starters', sTempUrl,
-                                     fErrorHandler=aErrors.append)
+        _sUrl, _sHash = find_data_pack('starters', sTempUrl,
+                                       fErrorHandler=aErrors.append)
+        # pylint: disable=unbalanced-tuple-unpacking
+        # by construction, this unpacking is safe
         [oExp] = aErrors
-        self.assertTrue(isinstance(oExp, ValueError))
+        # pylint: enable=unbalanced-tuple-unpacking
+        self.assertTrue(isinstance(oExp, json.decoder.JSONDecodeError))
+        self.assertTrue('Expecting value:' in str(oExp))
 
 
 if __name__ == "__main__":
-    unittest.main()
+    unittest.main()  # pragma: no cover
