@@ -1,6 +1,5 @@
-# test_ELDBDeckFileParser.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
 
@@ -50,31 +49,35 @@ http://www.example.url/in/description"
 # Needs to be a SutekhTestCase so the name mapping cache test works
 class TestELDBDeckFileParser(SutekhTest):
     """class for the ELDB deck file parser tests"""
+    # pylint: disable=too-many-public-methods
+    # unittest.TestCase, so many public methods
 
     def test_basic(self):
         """Run the input test."""
+        self.maxDiff = None
         oHolder = self._make_holder_from_string(ELDBDeckFileParser(),
-                ELDB_TEXT_EXAMPLE_1)
+                                                ELDB_TEXT_EXAMPLE_1)
 
         self.assertEqual(oHolder.name, "Test Deck")
         self.assertEqual(oHolder.author, "Anon Y Mous")
-        self.failUnless(oHolder.comment.startswith(
+        self.assertTrue(oHolder.comment.startswith(
             "Simple test deck."))
-        self.failUnless(oHolder.comment.endswith("in/description"))
+        self.assertTrue(oHolder.comment.endswith("in/description"))
 
         aCards = oHolder.get_cards()
 
         self.assertEqual(len(aCards), 10)
-        self.failUnless(("Test Vamp 1", 2) in aCards)
-        self.failUnless((u"L\xe1z\xe1r Dobrescu", 1) in aCards)
-        self.failUnless(('Inez "Nurse216" Villagrande', 1) in aCards)
-        self.failUnless(("Test Card 1", 2) in aCards)
-        self.failUnless(("Test Card 2", 4) in aCards)
-        self.failUnless(("Test Card 3", 12) in aCards)
-        self.failUnless(("Test Card 4", 1) in aCards)
-        self.failUnless(("Alan Sovereign (Advanced)", 1) in aCards)
-        self.failUnless(('Scapelli, The Family "Mechanic"', 1) in aCards)
-        self.failUnless(("The Path of Blood", 1) in aCards)
+        self.assertTrue(("Test Vamp 1", 2) in aCards)
+        self.assertTrue((u"L\xe1z\xe1r Dobrescu (Group 2)", 1) in aCards)
+        self.assertTrue(('Inez "Nurse216" Villagrande (Group 4)', 1) in aCards)
+        self.assertTrue(("Test Card 1", 2) in aCards)
+        self.assertTrue(("Test Card 2", 4) in aCards)
+        self.assertTrue(("Test Card 3", 12) in aCards)
+        self.assertTrue(("Test Card 4", 1) in aCards)
+        self.assertTrue(("Alan Sovereign (Group 3) (Advanced)", 1) in aCards)
+        self.assertTrue(('Scapelli, The Family "Mechanic"', 1) in aCards)
+        self.assertTrue(("The Path of Blood", 1) in aCards)
+
 
 if __name__ == "__main__":
-    unittest.main()
+    unittest.main()  # pragma: no cover
