@@ -1,14 +1,14 @@
-# test_ELDBHTMLParser.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
-# Copyright 2008 Neil Muller <drnmuller+sutekh@gmail.com>
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
+# Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
 
 """Test case for ELDB HTML parser"""
 
+import unittest
+
 from sutekh.io.ELDBHTMLParser import ELDBHTMLParser
 from sutekh.tests.TestCore import SutekhTest
-import unittest
 
 ELDB_HTML_EXAMPLE_1 = """<HTML>
 <HEAD>
@@ -41,25 +41,28 @@ ELDB_HTML_EXAMPLE_1 = """<HTML>
 
 class ELDBHTMLParserTests(SutekhTest):
     """class for the ELDB HTML input parser"""
+    # pylint: disable=too-many-public-methods
+    # unittest.TestCase, so many public methods
 
     def test_basic(self):
         """Run the input test."""
+        self.maxDiff = None
         oHolder = self._make_holder_from_string(ELDBHTMLParser(),
-                ELDB_HTML_EXAMPLE_1)
+                                                ELDB_HTML_EXAMPLE_1)
 
         self.assertEqual(oHolder.name, "Test Deck")
         self.assertEqual(oHolder.author, "Anon Y Mous")
-        self.failUnless(oHolder.comment.startswith("Simple test deck."))
+        self.assertTrue(oHolder.comment.startswith("Simple test deck."))
 
         aCards = oHolder.get_cards()
 
         self.assertEqual(len(aCards), 5)
-        self.failUnless(("Test Vamp 1", 1) in aCards)
-        self.failUnless(("Test Vamp 2", 2) in aCards)
-        self.failUnless(("Test Card 1", 2) in aCards)
-        self.failUnless(("Test Card 2", 3) in aCards)
-        self.failUnless(("Test Card 3", 2) in aCards)
+        self.assertTrue(("Test Vamp 1", 1) in aCards)
+        self.assertTrue(("Test Vamp 2", 2) in aCards)
+        self.assertTrue(("Test Card 1", 2) in aCards)
+        self.assertTrue(("Test Card 2", 3) in aCards)
+        self.assertTrue(("Test Card 3", 2) in aCards)
 
 
 if __name__ == "__main__":
-    unittest.main()
+    unittest.main()  # pragma: no cover
