@@ -1,6 +1,5 @@
-# test_ELDBInventoryParser.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
 
@@ -27,25 +26,29 @@ ELDB_INV_EXAMPLE_1 = """
 # Needs to be a SutekhTestCase so the name mapping cache test works
 class TestELDBInventoryParser(SutekhTest):
     """class for the ELDB inventory reading test"""
+    # pylint: disable=too-many-public-methods
+    # unittest.TestCase, so many public methods
 
     def test_basic(self):
         """Run the input test."""
+        self.maxDiff = None
         oHolder = self._make_holder_from_string(ELDBInventoryParser(),
-                ELDB_INV_EXAMPLE_1)
+                                                ELDB_INV_EXAMPLE_1)
 
         self.assertEqual(oHolder.name, '')  # DummyHolder default
 
         aCards = oHolder.get_cards()
 
         self.assertEqual(len(aCards), 6)
-        self.failUnless(("Test Vamp 1", 2) in aCards)
-        self.failUnless((u"L\xe1z\xe1r Dobrescu", 1) in aCards)
-        self.failUnless(("Test Card 1", 2) in aCards)
-        self.failUnless(("Test Card 2", 4) in aCards)
-        self.failUnless(("Test Card 3", 12) in aCards)
-        self.failUnless(("Test Card 4", 1) in aCards)
+        self.assertTrue(("Test Vamp 1", 2) in aCards)
+        self.assertTrue((u"L\xe1z\xe1r Dobrescu (Group 2)", 1) in aCards)
+        self.assertTrue(("Test Card 1", 2) in aCards)
+        self.assertTrue(("Test Card 2", 4) in aCards)
+        self.assertTrue(("Test Card 3", 12) in aCards)
+        self.assertTrue(("Test Card 4", 1) in aCards)
         # We don't need to test that the 0,0 entries have been skipped, as
         # that's covered by the len test
 
+
 if __name__ == "__main__":
-    unittest.main()
+    unittest.main()  # pragma: no cover
