@@ -1,28 +1,29 @@
-# test_IdentifyXMLFile.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
 
 """Test IdentifyXMLFile handling"""
 
-from sutekh.tests.TestCore import SutekhTest
+import unittest
+from io import StringIO
+
 from sutekh.io.IdentifyXMLFile import IdentifyXMLFile
+from sutekh.tests.TestCore import SutekhTest
 from sutekh.tests.io.test_AbstractCardSetParser import ACS_EXAMPLE_1
 from sutekh.tests.io.test_PhysicalCardSetParser import PCS_EXAMPLE_1
 from sutekh.tests.io.test_PhysicalCardParser import make_example_pcxml
-import unittest
-from StringIO import StringIO
 
 
 class TestIdentifyXMLFile(SutekhTest):
     """class for the IdentifyXMLFile tests"""
+    # pylint: disable=too-many-public-methods
+    # unittest.TestCase, so many public methods
 
     def test_identify_xml_file(self):
         """Test IdentifyXMLFile"""
-        # pylint: disable-msg=E1101
-        # E1101: SQLObject + PyProtocols magic confuses pylint
         # test IO
+        self.maxDiff = None
         sExample = make_example_pcxml()
 
         sTempFileName = self._create_tmp_file()
@@ -46,5 +47,6 @@ class TestIdentifyXMLFile(SutekhTest):
         oIdFile.parse(StringIO(PCS_EXAMPLE_1))
         self.assertEqual(oIdFile.type, 'PhysicalCardSet')
 
+
 if __name__ == "__main__":
-    unittest.main()
+    unittest.main()  # pragma: no cover
