@@ -1,17 +1,20 @@
-# test_WriteArdbText.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
 
 """Test Writing a card set to an ARDB deck XML file"""
 
-from sutekh.tests.TestCore import SutekhTest
-from sutekh.tests.core.test_PhysicalCardSet import make_set_1
-from sutekh.core.CardSetHolder import CardSetWrapper
+import unittest
+
+from sutekh.base.core.CardSetHolder import CardSetWrapper
+
+from sutekh.SutekhUtility import strip_group_from_name
+
 from sutekh.io.WriteArdbText import WriteArdbText
 from sutekh.io.ARDBTextParser import ARDBTextParser
-import unittest
+from sutekh.tests.TestCore import SutekhTest
+from sutekh.tests.core.test_PhysicalCardSet import make_set_1
 
 # This doesn't match the ARDB export for the same card set, due to
 # the outstanding issues in the Export implementation
@@ -20,38 +23,56 @@ Author : A test author
 Description :
 A test comment
 
-Crypt [4 vampires] Capacity min: 3 max: 7 average: 5.00
+Crypt [6 vampires] Capacity min: 3 max: 9 average: 6.00
 ------------------------------------------------------------
- 1x The Siamese            7 PRE SPI ani pro     Ahrimane:2
- 1x Alan Sovereign     Adv 6 AUS DOM for pre     Ventrue:3
- 1x Abebe                  4 nec obf thn         Samedi:4
- 1x Inez "Nurse216" Vi     3 inn                 Innocent (Imbued):4
+ 2x The Siamese            7 PRE SPI ani pro             Ahrimane:2
+ 1x Hektor                 9 CEL POT PRE QUI for Priscus !Brujah:4
+ 1x Alan Sovereign     Adv 6 AUS DOM for pre             Ventrue:3
+ 1x Abebe                  4 nec obf thn                 Samedi:4
+ 1x Inez "Nurse216" Vi     3 inn                         Innocent (Imbued):4
 
-Library [13 cards]
+Library [28 cards]
 ------------------------------------------------------------
 Action [2]
  2x Abbot
 
+Action Modifier [3]
+ 3x Aire of Elation
+
+Action Modifier/Combat [2]
+ 2x Swallowed by the Night
+
 Ally [1]
  1x Scapelli, The Family "Mechanic"
 
-Equipment [7]
+Combat [8]
+ 4x Immortal Grapple
+ 4x Walk of Flame
+
+Equipment [8]
  4x .44 Magnum
  2x AK-47
  1x Aaron's Feeding Razor
+ 1x An Anarch Manifesto
 
-Master [3]
+Master [3] (2 trifles)
  2x Abombwe
  1x The Path of Blood
 
+Reaction [1]
+ 1x Hide the Heart
+
 """
 
 
 class ArdbTextWriterTests(SutekhTest):
     """class for the ARDB text file writer tests"""
+    # pylint: disable=too-many-public-methods
+    # unittest.TestCase, so many public methods
 
     def test_deck_writer(self):
         """Test ARDB text file writing"""
+        self.maxDiff = None
         oPhysCardSet1 = make_set_1()
 
         # Check output
@@ -63,6 +84,7 @@ class ArdbTextWriterTests(SutekhTest):
 
     def test_roundtrip(self):
         """Test we can round-trip a deck"""
+        self.maxDiff = None
         oPhysCardSet1 = make_set_1()
         oParser = ARDBTextParser()
 
@@ -78,16 +100,20 @@ class ArdbTextWriterTests(SutekhTest):
         aCards = oHolder.get_cards()
         dSetCards = {}
         # Reformat cards in deck to match holder
+        # pylint: disable=not-an-iterable
+        # SQLObject confuses pylint
         for sName in [x.abstractCard.name for x in oPhysCardSet1.cards]:
             # We truncate Inez here to match the writer output
             if sName.startswith('Inez'):
                 sName = sName[:18]
+            sName = strip_group_from_name(sName)
             dSetCards.setdefault(sName, 0)
             dSetCards[sName] += 1
+        # pylint: enable=not-an-iterable
 
-        for sName, iCnt in dSetCards.iteritems():
-            self.failUnless((sName, iCnt) in aCards)
+        for sName, iCnt in dSetCards.items():
+            self.assertTrue((sName, iCnt) in aCards)
 
 
 if __name__ == "__main__":
-    unittest.main()
+    unittest.main()  # pragma: no cover
