@@ -1,34 +1,38 @@
-# test_ZipFileWrapper.py
-# -*- coding: utf8 -*-
-# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
+# -*- coding: utf-8 -*-
+# vim:fileencoding=utf-8 ai ts=4 sts=4 et sw=4
 # Copyright 2008 Neil Muller <drnlmuller+sutekh@gmail.com>
 # GPL - see COPYING for details
 
 """Test the Zip File Wrapper"""
 
-from sutekh.tests.TestCore import SutekhTest
-from sutekh.tests.core.test_PhysicalCardSet import CARD_SET_NAMES, \
-        get_phys_cards
-from sutekh.tests.io.test_AbstractCardSetParser import ACS_EXAMPLE_1, \
-        ACS_EXAMPLE_2
-from sutekh.tests.io.test_PhysicalCardSetParser import PCS_EXAMPLE_1
-from sutekh.tests.io.test_PhysicalCardParser import make_example_pcxml
-from sutekh.core.SutekhObjects import IPhysicalCardSet, PhysicalCardSet
-from sutekh.io.ZipFileWrapper import ZipFileWrapper
-from sutekh.gui.ProgressDialog import SutekhCountLogHandler
-from sutekh.core.CardSetUtilities import delete_physical_card_set
 import unittest
 import zipfile
 
+from sutekh.base.core.BaseTables import PhysicalCardSet
+from sutekh.base.core.BaseAdapters import IPhysicalCardSet
+from sutekh.base.core.CardSetUtilities import delete_physical_card_set
+from sutekh.base.gui.ProgressDialog import SutekhCountLogHandler
+
+from sutekh.io.ZipFileWrapper import ZipFileWrapper
+from sutekh.tests.TestCore import SutekhTest
+from sutekh.tests.core.test_PhysicalCardSet import (CARD_SET_NAMES,
+                                                    get_phys_cards)
+from sutekh.tests.io.test_AbstractCardSetParser import (ACS_EXAMPLE_1,
+                                                        ACS_EXAMPLE_2)
+from sutekh.tests.io.test_PhysicalCardSetParser import PCS_EXAMPLE_1
+from sutekh.tests.io.test_PhysicalCardParser import make_example_pcxml
+
 
 class ZipFileWrapperTest(SutekhTest):
     """class for the Zip File tests"""
+    # pylint: disable=too-many-public-methods
+    # unittest.TestCase, so many public methods
 
     def test_zip_file(self):
         """Test zip file handling"""
-        # pylint: disable-msg=E1101, R0915
-        # E1101: SQLObject + PyProtocols magic confuses pylint
-        # R0915: Want a single test case to avoid re-initialising the database
+        self.maxDiff = None
+        # pylint: disable=too-many-statements
+        # Want a single test case to avoid re-initialising the database
         sTempFileName = self._create_tmp_file()
         oZipFile = ZipFileWrapper(sTempFileName)
         aPhysCards = get_phys_cards()
@@ -36,11 +40,13 @@ class ZipFileWrapperTest(SutekhTest):
         oMyCollection = PhysicalCardSet(name='My Collection')
 
         for oCard in aPhysCards:
+            # pylint: disable=no-member
+            # SQLObject confuses pylint
             oMyCollection.addPhysicalCard(oCard.id)
             oMyCollection.syncUpdate()
 
         oPhysCardSet1 = PhysicalCardSet(name=CARD_SET_NAMES[0],
-                parent=oMyCollection)
+                                        parent=oMyCollection)
         oPhysCardSet1.comment = 'A test comment'
         oPhysCardSet1.author = 'A test author'
 
@@ -48,6 +54,8 @@ class ZipFileWrapperTest(SutekhTest):
         self.assertEqual(oPhysCardSet1.parent.id, oMyCollection.id)
 
         for iLoop in range(5):
+            # pylint: disable=no-member
+            # SQLObject confuses pylint
             oPhysCardSet1.addPhysicalCard(aPhysCards[iLoop].id)
             oPhysCardSet1.syncUpdate()
             if iLoop > 3:
@@ -60,6 +68,8 @@ class ZipFileWrapperTest(SutekhTest):
         oPhysCardSet2.author = 'A different author'
 
         for iLoop in range(2, 7):
+            # pylint: disable=no-member
+            # SQLObject confuses pylint
             oPhysCardSet2.addPhysicalCard(aPhysCards[iLoop].id)
             oPhysCardSet2.syncUpdate()
 
@@ -71,12 +81,15 @@ class ZipFileWrapperTest(SutekhTest):
         self.assertTrue(oPhysCardSet2.name in dEntries)
         self.assertTrue(oPhysCardSet1.name in dEntries)
         self.assertTrue(oMyCollection.name in dEntries)
-        self.assertEquals(dEntries[oPhysCardSet1.name][2], oMyCollection.name)
+        self.assertEqual(dEntries[oPhysCardSet1.name][2], oMyCollection.name)
 
         # Check it loads correctly
         # Destroy some existing data
+        # pylint: disable=not-an-iterable
+        # SQLObject confuses pylint
         aCardSet1 = sorted([x.abstractCard.name for x in oPhysCardSet1.cards])
         aCardSet2 = sorted([x.abstractCard.name for x in oPhysCardSet2.cards])
+        # pylint: enable=not-an-iterable
 
         delete_physical_card_set(oMyCollection.name)
         delete_physical_card_set(oPhysCardSet1.name)
@@ -97,21 +110,20 @@ class ZipFileWrapperTest(SutekhTest):
         self.assertNotEqual(oPhysCardSet1.parent, None)
         self.assertEqual(oPhysCardSet1.parent.id, oMyCollection.id)
         self.assertEqual(sorted([x.abstractCard.name for x in
-            oPhysCardSet1.cards]), aCardSet1)
+                                 oPhysCardSet1.cards]), aCardSet1)
         self.assertEqual(oPhysCardSet2.parent, None)
         self.assertEqual(sorted([x.abstractCard.name for x in
-            oPhysCardSet2.cards]), aCardSet2)
+                                 oPhysCardSet2.cards]), aCardSet2)
 
         self.assertEqual(sorted([x.abstractCard.name for x in
-            oMyCollection.cards]), sorted([x.abstractCard.name for x in
-                aPhysCards]))
+                                 oMyCollection.cards]),
+                         sorted([x.abstractCard.name for x in aPhysCards]))
         self.assertEqual(len(oPhysCardSet1.cards), 6)
         self.assertEqual(len(oPhysCardSet2.cards), 5)
 
     def test_read_single(self):
         """Check read_single_works"""
-        # pylint: disable-msg=E1101
-        # E1101: SQLObject + PyProtocols magic confuses pylint
+        self.maxDiff = None
         sTempFileName = self._create_tmp_file()
         oZipFile = ZipFileWrapper(sTempFileName)
         aPhysCards = get_phys_cards()
@@ -119,6 +131,8 @@ class ZipFileWrapperTest(SutekhTest):
         oMyCollection = PhysicalCardSet(name='My Collection')
 
         for oCard in aPhysCards:
+            # pylint: disable=no-member
+            # SQLObject confuses pylint
             oMyCollection.addPhysicalCard(oCard.id)
             oMyCollection.syncUpdate()
 
@@ -133,13 +147,12 @@ class ZipFileWrapperTest(SutekhTest):
         oMyCollection = IPhysicalCardSet('My Collection')
 
         self.assertEqual(sorted([x.abstractCard.name for x in
-            oMyCollection.cards]), sorted([x.abstractCard.name for x in
-                aPhysCards]))
+                                 oMyCollection.cards]),
+                         sorted([x.abstractCard.name for x in aPhysCards]))
 
     def test_old_format(self):
         """Test that an old zip file loads correctly"""
-        # pylint: disable-msg=E1101
-        # E1101: SQLObject + PyProtocols magic confuses pylint
+        self.maxDiff = None
         # Create a test zipfile with old data
         sPhysicalCards = make_example_pcxml()
 
@@ -153,12 +166,12 @@ class ZipFileWrapperTest(SutekhTest):
         oZipFile.close()
 
         # Check it loads correctly
-        oZipFile = ZipFileWrapper(sTempFileName)
-        oZipFile.do_restore_from_zip(oLogHandler=oHandler)
+        oZipWrapper = ZipFileWrapper(sTempFileName)
+        oZipWrapper.do_restore_from_zip(oLogHandler=oHandler)
         self.assertEqual(oHandler.fTot, 4)
 
         oMyCollection = IPhysicalCardSet("My Collection")
-        assert(len(oMyCollection.cards) == 1)
+        self.assertEqual(len(oMyCollection.cards), 1)
 
         oPhysCardSet1 = IPhysicalCardSet('Test Set 1')
 
@@ -175,5 +188,6 @@ class ZipFileWrapperTest(SutekhTest):
         self.assertEqual(oACSCardSet1.parent, None)
         self.assertEqual(oACSCardSet2.parent, None)
 
+
 if __name__ == "__main__":
-    unittest.main()
+    unittest.main()  # pragma: no cover
